/*! elementor - v3.5.6 - 28-02-2022 */
@charset "UTF-8";
.elementor-control-unit-1 {
  width: 27px; }

.elementor-control-unit-2 {
  width: 54px; }

.elementor-control-unit-3 {
  width: 81px; }

.elementor-control-unit-4 {
  width: 108px; }

.elementor-control-unit-5 {
  max-width: 400px;
  width: 52%; }

*, :before, :after {
  margin: 0;
  padding: 0;
  -webkit-box-sizing: border-box;
          box-sizing: border-box; }

body,
html {
  height: 100%; }

html {
  background-color: #F1F1F1; }

iframe,
img {
  border: 0 none; }

li {
  list-style: none; }

a {
  text-decoration: none; }

body {
  color: #6d7882;
  font-family: Roboto, Arial, Helvetica, Verdana, sans-serif;
  font-size: 13px;
  font-weight: normal;
  line-height: 1;
  text-decoration: none;
  text-transform: none;
  overflow: hidden; }
  body:after {
    content: '';
    position: absolute;
    top: 0;
    left: 0;
    height: 100%;
    width: 0;
    background-color: #71d7f7;
    -webkit-transition: width .5s;
    -o-transition: width .5s;
    transition: width .5s; }
  body a {
    color: #71d7f7; }
    body a:hover {
      color: #93003c; }
  body.elementor-editor-active #elementor-mode-switcher-preview .eicon:before {
    content: ""; }
  body.elementor-editor-preview {
    --e-preview-width: 100%; }
    body.elementor-editor-preview #elementor-mode-switcher-preview .eicon:before {
      content: ""; }
  body.elementor-navigator--dock-hint:after {
    width: 30px; }

#elementor-editor-wrapper {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  width: 100%;
  height: 100vh; }

#elementor-panel:not(.ui-resizable-resizing),
#elementor-preview:not(.ui-resizable-resizing) {
  -webkit-transition: margin .5s ease-in-out, width .5s ease-in-out;
  -o-transition: margin .5s ease-in-out, width .5s ease-in-out;
  transition: margin .5s ease-in-out, width .5s ease-in-out; }

#elementor-loading {
  position: fixed;
  top: 0;
  left: 0;
  bottom: 0;
  right: 0;
  background: #f1f3f5;
  z-index: 9999; }

#elementor-preview-loading {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  -webkit-box-pack: center;
      -ms-flex-pack: center;
          justify-content: center;
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  background-color: #fff; }
  #elementor-preview-loading i {
    color: #d5dadf;
    font-size: 50px; }

#elementor-fatal-error-dialog button.dialog-ok {
  color: #71d7f7; }

#elementor-fatal-error-dialog .dialog-header {
  color: #6d7882; }

#elementor-flexbox-attention-dialog .dialog-cancel {
  color: #39b54a; }

#elementor-flexbox-attention-dialog .dialog-ok {
  color: #6d7882; }

.elementor-nerd-box {
  padding: 30px;
  text-align: center; }
  .elementor-nerd-box-icon {
    width: 100px;
    margin-right: 10px; }
  .elementor-nerd-box-title {
    margin-top: 20px;
    font-size: 16px;
    font-weight: bold;
    line-height: 1.4; }
  .elementor-nerd-box-message {
    margin-top: 5px;
    line-height: 1.8;
    font-size: 11px; }
  .elementor-nerd-box .elementor-button.elementor-nerd-box-link {
    background-color: #93003c;
    color: #ffffff;
    padding: 7px 25px;
    margin-top: 20px;
    -webkit-box-shadow: 0 0 1px rgba(0, 0, 0, 0.1), 0 2px 2px rgba(0, 0, 0, 0.1);
            box-shadow: 0 0 1px rgba(0, 0, 0, 0.1), 0 2px 2px rgba(0, 0, 0, 0.1);
    -webkit-transition: .5s;
    -o-transition: .5s;
    transition: .5s; }
    .elementor-nerd-box .elementor-button.elementor-nerd-box-link:hover {
      background-color: #c60051; }

.eicon-nerd:hover:before {
  content: '\e8b7'; }

.eicon-nerd:active:before {
  content: '\e8b6'; }

.e-group-control-header {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
      -ms-flex-pack: justify;
          justify-content: space-between;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  font-weight: bold;
  font-size: 12px;
  padding: 10px;
  -webkit-box-shadow: 0px 2px 8px rgba(0, 0, 0, 0.1);
          box-shadow: 0px 2px 8px rgba(0, 0, 0, 0.1);
  margin-bottom: 15px; }

.e-control-tools {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex; }

.e-control-tool {
  width: 20px;
  height: 20px;
  display: -webkit-inline-box;
  display: -ms-inline-flexbox;
  display: inline-flex;
  -webkit-border-radius: 3px;
          border-radius: 3px;
  margin: 0 3px 0;
  border: 0;
  position: relative;
  background-color: #fff; }
  .e-control-tool:not(.e-control-tool-disabled) {
    -webkit-box-shadow: 0 1px 5px rgba(0, 0, 0, 0.1);
            box-shadow: 0 1px 5px rgba(0, 0, 0, 0.1);
    cursor: pointer; }
  .e-control-tool-disabled {
    background: #e6e9ec;
    pointer-events: none; }
    .e-control-tool-disabled i {
      color: #fff; }
  .e-control-tool i {
    position: absolute;
    top: 50%;
    left: 50%;
    -webkit-transform: translateX(-50%) translateY(-50%);
        -ms-transform: translateX(-50%) translateY(-50%);
            transform: translateX(-50%) translateY(-50%);
    color: #6d7882;
    font-size: 13px; }

#e-enable-unfiltered-files-dialog .dialog-confirm-ok {
  color: #39b54a; }

i.eicon-tilted {
  -webkit-transform: rotate(90deg);
      -ms-transform: rotate(90deg);
          transform: rotate(90deg); }

.elementor-loader-wrapper {
  position: absolute;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
      -ms-transform: translate(-50%, -50%);
          transform: translate(-50%, -50%);
  width: 300px;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -ms-flex-wrap: wrap;
      flex-wrap: wrap;
  -webkit-box-pack: center;
      -ms-flex-pack: center;
          justify-content: center; }

.elementor-loader {
  -webkit-border-radius: 50%;
          border-radius: 50%;
  padding: 40px;
  height: 150px;
  width: 150px;
  background-color: rgba(255, 255, 255, 0.9);
  -webkit-box-sizing: border-box;
          box-sizing: border-box;
  -webkit-box-shadow: 2px 2px 20px 4px rgba(0, 0, 0, 0.02);
          box-shadow: 2px 2px 20px 4px rgba(0, 0, 0, 0.02); }

.elementor-loader-boxes {
  height: 100%;
  width: 100%;
  position: relative; }

.elementor-loader-box {
  position: absolute;
  background-color: #d5dadf;
  -webkit-animation: load 1.8s linear infinite;
          animation: load 1.8s linear infinite; }
  .elementor-loader-box:nth-of-type(1) {
    width: 20%;
    height: 100%;
    left: 0;
    top: 0; }
  .elementor-loader-box:not(:nth-of-type(1)) {
    right: 0;
    height: 20%;
    width: 60%; }
  .elementor-loader-box:nth-of-type(2) {
    top: 0;
    -webkit-animation-delay: -0.45s;
            animation-delay: -0.45s; }
  .elementor-loader-box:nth-of-type(3) {
    top: 40%;
    -webkit-animation-delay: -0.9s;
            animation-delay: -0.9s; }
  .elementor-loader-box:nth-of-type(4) {
    bottom: 0;
    -webkit-animation-delay: -1.35s;
            animation-delay: -1.35s; }

.elementor-loading-title {
  color: #a4afb7;
  text-align: center;
  text-transform: uppercase;
  margin-top: 30px;
  letter-spacing: 7px;
  text-indent: 7px;
  font-size: 10px;
  width: 100%; }

.elementor-button {
  font-family: Roboto, Arial, Helvetica, Verdana, sans-serif;
  font-weight: 500;
  text-transform: uppercase;
  outline: none;
  border: none;
  -webkit-border-radius: 3px;
          border-radius: 3px;
  -webkit-transition-property: background, color, opacity, -webkit-box-shadow;
  transition-property: background, color, opacity, -webkit-box-shadow;
  -o-transition-property: background, color, box-shadow, opacity;
  transition-property: background, color, box-shadow, opacity;
  transition-property: background, color, box-shadow, opacity, -webkit-box-shadow;
  -webkit-transition-duration: .3s;
       -o-transition-duration: .3s;
          transition-duration: .3s; }
  .elementor-button:hover {
    border: none; }
  .elementor-button:not([disabled]) {
    cursor: pointer; }
  .elementor-button:not(.elementor-button-state) .elementor-state-icon {
    display: none; }
  .elementor-button.elementor-button-success {
    color: #fff; }
    .elementor-button.elementor-button-success[disabled] {
      background-color: #c2cbd2; }
    .elementor-button.elementor-button-success:not([disabled]) {
      background-color: #39b54a; }
      .elementor-button.elementor-button-success:not([disabled]):hover {
        opacity: 0.85;
        -webkit-box-shadow: 0 0 2px rgba(0, 0, 0, 0.12), 0 2px 2px rgba(0, 0, 0, 0.2);
                box-shadow: 0 0 2px rgba(0, 0, 0, 0.12), 0 2px 2px rgba(0, 0, 0, 0.2); }
      .elementor-button.elementor-button-success:not([disabled]):active {
        -webkit-box-shadow: 0 5px 10px rgba(0, 0, 0, 0.19), 0 3px 3px rgba(0, 0, 0, 0.1);
                box-shadow: 0 5px 10px rgba(0, 0, 0, 0.19), 0 3px 3px rgba(0, 0, 0, 0.1); }
  .elementor-button.elementor-button-warning {
    background-color: #a4afb7;
    color: #fff; }
    .elementor-button.elementor-button-warning[disabled] {
      background-color: #c2cbd2; }
    .elementor-button.elementor-button-warning:not([disabled]):hover {
      background-color: #b01b1b;
      opacity: 0.85;
      -webkit-box-shadow: 0 0 2px rgba(0, 0, 0, 0.12), 0 2px 2px rgba(0, 0, 0, 0.2);
              box-shadow: 0 0 2px rgba(0, 0, 0, 0.12), 0 2px 2px rgba(0, 0, 0, 0.2); }
    .elementor-button.elementor-button-warning:not([disabled]):active {
      -webkit-box-shadow: 0 5px 10px rgba(0, 0, 0, 0.19), 0 3px 3px rgba(0, 0, 0, 0.1);
              box-shadow: 0 5px 10px rgba(0, 0, 0, 0.19), 0 3px 3px rgba(0, 0, 0, 0.1); }
  .elementor-button.elementor-button-danger {
    background-color: #d72b3f;
    color: #fff; }
    .elementor-button.elementor-button-danger[disabled] {
      background-color: #c2cbd2; }
    .elementor-button.elementor-button-danger:not([disabled]):hover {
      opacity: 0.85;
      -webkit-box-shadow: 0 0 2px rgba(0, 0, 0, 0.12), 0 2px 2px rgba(0, 0, 0, 0.2);
              box-shadow: 0 0 2px rgba(0, 0, 0, 0.12), 0 2px 2px rgba(0, 0, 0, 0.2); }
    .elementor-button.elementor-button-danger:not([disabled]):active {
      -webkit-box-shadow: 0 5px 10px rgba(0, 0, 0, 0.19), 0 3px 3px rgba(0, 0, 0, 0.1);
              box-shadow: 0 5px 10px rgba(0, 0, 0, 0.19), 0 3px 3px rgba(0, 0, 0, 0.1); }
  .elementor-button.elementor-edit-template {
    display: inline-block;
    margin-top: 15px;
    color: #fff; }
  .elementor-button.elementor-button-default {
    background-color: #a4afb7;
    color: #fff;
    font-size: 11px;
    padding: 7px 21px; }
    .elementor-button.elementor-button-default:hover {
      background-color: #6d7882;
      -webkit-box-shadow: 0 0 2px rgba(0, 0, 0, 0.12), 0 2px 2px rgba(0, 0, 0, 0.2);
              box-shadow: 0 0 2px rgba(0, 0, 0, 0.12), 0 2px 2px rgba(0, 0, 0, 0.2); }
    .elementor-button.elementor-button-default:active {
      -webkit-box-shadow: 0 5px 10px rgba(0, 0, 0, 0.19), 0 3px 3px rgba(0, 0, 0, 0.1);
              box-shadow: 0 5px 10px rgba(0, 0, 0, 0.19), 0 3px 3px rgba(0, 0, 0, 0.1); }
    .elementor-button.elementor-button-default:visited {
      color: #fff; }
  .elementor-button.elementor-button-go-pro {
    background-color: #93003c; }
  .elementor-button i {
    margin-left: 10px; }

input, select, textarea, .elementor-input-style {
  -webkit-border-radius: 3px;
          border-radius: 3px;
  font-size: 12px;
  width: 100%;
  background: none;
  -webkit-box-shadow: none;
          box-shadow: none;
  color: #6d7882;
  border: 1px solid;
  outline: none; }
  input:not(:focus), select:not(:focus), textarea:not(:focus), .elementor-input-style:not(:focus) {
    border-color: #d5dadf; }
  input:focus, input:focus + .elementor-control-dynamic-switcher, select:focus, select:focus + .elementor-control-dynamic-switcher, textarea:focus, textarea:focus + .elementor-control-dynamic-switcher, .elementor-input-style:focus, .elementor-input-style:focus + .elementor-control-dynamic-switcher {
    border-color: #a4afb7; }
  input::-webkit-input-placeholder, select::-webkit-input-placeholder, textarea::-webkit-input-placeholder, .elementor-input-style::-webkit-input-placeholder {
    color: #a4afb7; }
  input::-moz-placeholder, select::-moz-placeholder, textarea::-moz-placeholder, .elementor-input-style::-moz-placeholder {
    color: #a4afb7; }
  input::-ms-input-placeholder, select::-ms-input-placeholder, textarea::-ms-input-placeholder, .elementor-input-style::-ms-input-placeholder {
    color: #a4afb7; }
  input::placeholder, select::placeholder, textarea::placeholder, .elementor-input-style::placeholder {
    color: #a4afb7; }

.elementor-error input, .elementor-error select, .elementor-error textarea {
  border-color: #b01b1b; }

input {
  min-width: 0; }

input, textarea, .elementor-input-style {
  padding: 5px; }

textarea, .elementor-input-style {
  resize: vertical; }

input[type="checkbox"],
input[type="radio"] {
  height: auto;
  width: auto; }

input[disabled] {
  background-color: #e6e9ec;
  cursor: not-allowed;
  opacity: 1; }

select {
  outline: none;
  height: 27px; }

/*
 * Container style
 */
.ps {
  overflow: hidden !important;
  overflow-anchor: none;
  -ms-touch-action: auto;
      touch-action: auto; }

/*
 * Scrollbar rail styles
 */
.ps__rail-y {
  display: none;
  opacity: 0;
  -webkit-transition: background-color .2s linear, opacity .2s linear;
  -o-transition: background-color .2s linear, opacity .2s linear;
  transition: background-color .2s linear, opacity .2s linear;
  width: 15px;
  /* there must be 'right' or 'left' for ps__rail-y */
  right: 0;
  left: initial !important;
  /* please don't change 'position' */
  position: absolute; }

.ps--active-y > .ps__rail-y {
  display: block;
  background-color: transparent; }

.ps:hover > .ps__rail-y,
.ps--focus > .ps__rail-y,
.ps--scrolling-y > .ps__rail-y {
  opacity: 0.6; }

.ps .ps__rail-y:hover,
.ps .ps__rail-y:focus,
.ps .ps__rail-y.ps--clicking {
  opacity: 0.9; }

.ps__thumb-y {
  background-color: #aaa;
  -webkit-border-radius: 6px;
          border-radius: 6px;
  -webkit-transition: background-color .2s linear, width .2s ease-in-out;
  -o-transition: background-color .2s linear, width .2s ease-in-out;
  transition: background-color .2s linear, width .2s ease-in-out;
  width: 6px;
  /* there must be 'right' for ps__thumb-y */
  right: 2px;
  /* please don't change 'position' */
  position: absolute; }

.ps__rail-y:hover > .ps__thumb-y,
.ps__rail-y:focus > .ps__thumb-y,
.ps__rail-y.ps--clicking .ps__thumb-y {
  background-color: #999;
  width: 6px; }

/* Make clicks pass-through */
#nprogress {
  pointer-events: none; }

#nprogress .bar {
  background: #39b54a;
  position: fixed;
  z-index: 1031;
  top: 0;
  left: 0;
  width: 100%;
  height: 2px; }

/* Fancy blur effect */
#nprogress .peg {
  display: block;
  position: absolute;
  right: 0;
  width: 100px;
  height: 100%;
  -webkit-box-shadow: 0 0 10px #39b54a, 0 0 5px #39b54a;
          box-shadow: 0 0 10px #39b54a, 0 0 5px #39b54a;
  opacity: 1.0;
  -webkit-transform: rotate(3deg) translate(0px, -4px);
      -ms-transform: rotate(3deg) translate(0px, -4px);
          transform: rotate(3deg) translate(0px, -4px); }

/* Remove these to get rid of the spinner */
#nprogress .spinner {
  display: none;
  position: fixed;
  z-index: 1031;
  top: 15px;
  right: 15px; }

#nprogress .spinner-icon {
  width: 18px;
  height: 18px;
  -webkit-box-sizing: border-box;
          box-sizing: border-box;
  border: solid 2px transparent;
  border-top-color: #39b54a;
  border-left-color: #39b54a;
  -webkit-border-radius: 50%;
          border-radius: 50%;
  -webkit-animation: nprogress-spinner 400ms linear infinite;
          animation: nprogress-spinner 400ms linear infinite; }

.nprogress-custom-parent {
  overflow: hidden;
  position: relative; }

.nprogress-custom-parent #nprogress .spinner,
.nprogress-custom-parent #nprogress .bar {
  position: absolute; }

@-webkit-keyframes nprogress-spinner {
  0% {
    -webkit-transform: rotate(0deg);
            transform: rotate(0deg); }
  100% {
    -webkit-transform: rotate(360deg);
            transform: rotate(360deg); } }

@keyframes nprogress-spinner {
  0% {
    -webkit-transform: rotate(0deg);
            transform: rotate(0deg); }
  100% {
    -webkit-transform: rotate(360deg);
            transform: rotate(360deg); } }

#nprogress .bar,
#nprogress .spinner {
  z-index: 100000; }

:root {
  --e-is-preview-mode: 0; }
  @media (max-width: 1439px) {
    :root {
      --e-editor-panel-width: 280px; } }
  @media (min-width: 1440px) {
    :root {
      --e-editor-panel-width: 300px; } }

.elementor-panel {
  position: relative;
  height: 100%;
  -webkit-margin-start: calc(-1 * var(--e-editor-panel-width) * var(--e-is-preview-mode));
          margin-inline-start: calc(-1 * var(--e-editor-panel-width) * var(--e-is-preview-mode));
  width: var(--e-editor-panel-width);
  overflow: visible;
  background-color: #e6e9ec;
  z-index: 1;
  font-family: Roboto, Arial, Helvetica, Verdana, sans-serif;
  font-size: 13px;
  right: 0; }
  .elementor-editor-preview .elementor-panel {
    --e-is-preview-mode: 1; }
    .elementor-editor-preview .elementor-panel > .ui-resizable-e, .elementor-editor-preview .elementor-panel > .ui-resizable-w {
      display: none; }
  .elementor-panel .ps__rail-y {
    z-index: 2; }
  .elementor-panel .elementor-responsive-panel {
    padding: 5px 10px;
    display: grid;
    gap: 10px;
    grid-template-columns: repeat(auto-fill, minmax(Min(135px, calc( 50% - 5px)), 1fr)); }
    .elementor-panel .elementor-responsive-panel > .e-responsive-panel-stretch {
      grid-column: 1 / -1; }
  .elementor-panel ::-moz-selection {
    background: #5bc0de;
    color: #ffffff; }
  .elementor-panel ::selection {
    background: #5bc0de;
    color: #ffffff; }
  .elementor-panel a {
    color: #93003c; }
  .elementor-panel h1,
  .elementor-panel h2,
  .elementor-panel h3,
  .elementor-panel h4,
  .elementor-panel h5,
  .elementor-panel h6 {
    font-size: 100%;
    font-weight: normal; }
  .elementor-panel abbr,
  .elementor-panel acronym {
    border: 0;
    font-variant: normal; }
  .elementor-panel sup {
    vertical-align: text-top; }
  .elementor-panel sub {
    vertical-align: text-bottom; }
  .elementor-panel img {
    max-width: 100%;
    height: auto;
    border: 0; }
  .elementor-panel ::-moz-focus-inner {
    padding: 0;
    border: 0; }
  .elementor-panel :focus {
    outline: 0; }
  .elementor-panel .elementor-panel-box {
    margin-top: 10px;
    background-color: #fff; }
  .elementor-panel .elementor-panel-box-content {
    padding: 20px 20px 10px; }
  .elementor-panel .elementor-button {
    display: inline-block; }
  .elementor-panel .elementor-panel-alert {
    background-color: #fcfcfc;
    padding: 15px;
    border-right: 3px solid transparent;
    position: relative;
    font-size: 12px;
    font-weight: 300;
    font-style: italic;
    line-height: 1.5;
    text-align: right;
    -webkit-border-radius: 3px 0 0 3px;
            border-radius: 3px 0 0 3px;
    -webkit-box-shadow: 0 1px 4px 0 rgba(0, 0, 0, 0.07);
            box-shadow: 0 1px 4px 0 rgba(0, 0, 0, 0.07); }
    .elementor-panel .elementor-panel-alert a {
      color: inherit; }
    .elementor-panel .elementor-panel-alert.elementor-panel-alert-info {
      border-color: #71d7f7;
      background-color: #f3fcff; }
    .elementor-panel .elementor-panel-alert.elementor-panel-alert-success {
      border-color: #39b54a; }
    .elementor-panel .elementor-panel-alert.elementor-panel-alert-warning {
      border-color: #fcb92c; }
    .elementor-panel .elementor-panel-alert.elementor-panel-alert-danger {
      border-color: #d72b3f; }
  .elementor-panel .elementor-label {
    display: inline;
    padding: .2em .6em .3em;
    font-size: 75%;
    font-weight: 700;
    line-height: 1;
    color: #fff;
    text-align: center;
    white-space: nowrap;
    vertical-align: baseline;
    -webkit-border-radius: .25em;
            border-radius: .25em;
    text-transform: capitalize; }
    .elementor-panel .elementor-label.elementor-label-default {
      background-color: #a4afb7; }
    .elementor-panel .elementor-label.elementor-label-info {
      background-color: #5bc0de; }
    .elementor-panel .elementor-label.elementor-label-success {
      background-color: #5cb85c; }
    .elementor-panel .elementor-label.elementor-label-warning {
      background-color: #f0ad4e; }
    .elementor-panel .elementor-label.elementor-label-danger {
      background-color: #d9534f; }
  .elementor-panel .elementor-descriptor, .elementor-panel .elementor-control-field-description {
    font-size: 11px;
    font-style: italic;
    line-height: 1.4;
    color: #a4afb7; }
  .elementor-panel .elementor-controls-popover {
    display: none;
    position: absolute;
    -webkit-box-shadow: 0 2px 15px rgba(0, 0, 0, 0.3);
            box-shadow: 0 2px 15px rgba(0, 0, 0, 0.3);
    -webkit-border-radius: 3px;
            border-radius: 3px;
    left: 0;
    right: 0;
    margin: -4px auto 5px;
    padding-top: 15px;
    width: 90%;
    z-index: 10000;
    background-color: #fff; }
    .elementor-panel .elementor-controls-popover:before {
      content: '';
      position: absolute;
      top: -16px;
      left: 22px;
      border: 8px solid transparent;
      border-bottom-color: #fff; }
    .elementor-panel .elementor-controls-popover div.elementor-control {
      background-color: transparent; }
      .elementor-panel .elementor-controls-popover div.elementor-control:before {
        content: none; }
  .elementor-panel #elementor-controls .pojo-widget-button-collapse {
    display: none; }
  .elementor-panel #elementor-panel-global .elementor-nerd-box .elementor-nerd-box-icon {
    margin-top: 20px; }
  .elementor-panel #elementor-panel-header {
    display: table;
    height: 40px;
    width: 100%;
    background-color: #93003c;
    color: #fff; }
    .elementor-panel #elementor-panel-header > * {
      display: table-cell;
      vertical-align: middle;
      text-align: center; }
  .elementor-panel .elementor-header-button {
    width: 40px; }
    .elementor-panel .elementor-header-button .elementor-icon {
      cursor: pointer;
      display: block;
      font-size: 19px;
      height: 40px;
      line-height: 40px;
      -webkit-transition: all 0.3s;
      -o-transition: all 0.3s;
      transition: all 0.3s; }
      .elementor-panel .elementor-header-button .elementor-icon.eicon-menu-bar {
        font-size: 18px; }
      .elementor-panel .elementor-header-button .elementor-icon:hover {
        color: #d5dadf; }
  .elementor-panel #elementor-panel-header-title {
    font-size: 15px; }
    .elementor-panel #elementor-panel-header-title img {
      width: 90px; }
  .elementor-panel #elementor-panel-elements-categories {
    padding-bottom: 10px; }
  .elementor-panel .elementor-panel-category {
    position: relative; }
    .elementor-panel .elementor-panel-category:first-child .elementor-panel-category-title {
      padding-top: 14px; }
    .elementor-panel .elementor-panel-category.elementor-active .elementor-panel-category-title:before {
      -webkit-transform: rotate(-90deg);
          -ms-transform: rotate(-90deg);
              transform: rotate(-90deg); }
    .elementor-panel .elementor-panel-category:not(.elementor-active):after {
      content: '';
      position: absolute;
      left: 15px;
      right: 15px;
      bottom: 0;
      height: 8px;
      background: -webkit-gradient(linear, left top, left bottom, from(rgba(0, 0, 0, 0.03)), to(transparent));
      background: -webkit-linear-gradient(rgba(0, 0, 0, 0.03), transparent);
      background: -o-linear-gradient(rgba(0, 0, 0, 0.03), transparent);
      background: linear-gradient(rgba(0, 0, 0, 0.03), transparent);
      -webkit-transform: translateY(100%);
          -ms-transform: translateY(100%);
              transform: translateY(100%); }
    .elementor-panel .elementor-panel-category-title {
      margin: 0 15px;
      padding: 20px 0;
      position: relative;
      text-transform: uppercase;
      font-size: 11px;
      cursor: pointer; }
      .elementor-panel .elementor-panel-category-title:before {
        content: "";
        font-family: eicons;
        position: absolute;
        left: 0;
        -webkit-transition: -webkit-transform .3s;
        transition: -webkit-transform .3s;
        -o-transition: transform .3s;
        transition: transform .3s;
        transition: transform .3s, -webkit-transform .3s; }
    .elementor-panel .elementor-panel-category-items {
      padding: 0 10px; }
      .elementor-panel .elementor-panel-category-items-empty {
        grid-column-start: 1;
        grid-column-end: 3; }
  .elementor-panel .elementor-panel-scheme-title {
    padding: 10px 20px;
    margin-top: 10px; }
  .elementor-panel .elementor-panel-scheme-description {
    padding: 20px 20px 0; }
  .elementor-panel .elementor-panel-scheme-buttons {
    padding: 0 20px;
    display: table;
    table-layout: fixed;
    width: 100%;
    height: 40px;
    background-color: #fff;
    -webkit-box-shadow: 0 0 8px rgba(0, 0, 0, 0.1);
            box-shadow: 0 0 8px rgba(0, 0, 0, 0.1); }
    .elementor-panel .elementor-panel-scheme-buttons .elementor-button {
      font-family: Roboto, Arial, Helvetica, Verdana, sans-serif;
      font-size: 11px;
      font-weight: 400; }
  .elementor-panel .elementor-panel-scheme-button-wrapper {
    display: table-cell;
    vertical-align: middle;
    text-align: center; }
    .elementor-panel .elementor-panel-scheme-button-wrapper:first-child {
      text-align: right; }
    .elementor-panel .elementor-panel-scheme-button-wrapper:last-child {
      text-align: left; }
  .elementor-panel .elementor-panel-scheme-save .elementor-button {
    padding: 6px 18px; }
  .elementor-panel .elementor-panel-scheme-reset .elementor-button, .elementor-panel .elementor-panel-scheme-discard .elementor-button {
    color: #a4afb7;
    background: none; }
  .elementor-panel .elementor-panel-scheme-color .elementor-panel-scheme-items {
    position: relative;
    display: grid;
    grid-template-columns: repeat(4, 27px);
    -webkit-box-pack: justify;
        -ms-flex-pack: justify;
            justify-content: space-between; }
  .elementor-panel .elementor-panel-scheme-color-title {
    text-align: center;
    text-transform: uppercase;
    margin: 10px 0;
    color: #c2cbd2;
    font-size: 8px; }
  .elementor-panel .elementor-panel-scheme-typography-item {
    display: table;
    table-layout: fixed;
    width: 100%;
    margin-bottom: 15px; }
    .elementor-panel .elementor-panel-scheme-typography-item > * {
      display: table-cell;
      vertical-align: middle; }
  .elementor-panel .elementor-panel-scheme-typography-item-value select, .elementor-panel .elementor-panel-scheme-typography-item-value input {
    width: 100%; }
  .elementor-panel .elementor-panel-scheme-item:not(.elementor-open) .elementor-panel-scheme-typography-items {
    display: none; }
  .elementor-panel .elementor-panel-scheme-color-system-scheme {
    margin-bottom: 10px; }
    .elementor-panel .elementor-panel-scheme-color-system-scheme .elementor-title {
      font-size: 11px;
      color: #a4afb7;
      font-style: italic;
      margin-top: 5px; }
  .elementor-panel .elementor-panel-scheme-color-system-items {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-transition: border .5s;
    -o-transition: border .5s;
    transition: border .5s;
    overflow: hidden;
    padding: 3px;
    -webkit-border-radius: 3px;
            border-radius: 3px;
    border: 1px solid #d5dadf;
    cursor: pointer; }
    .elementor-panel .elementor-panel-scheme-color-system-items:hover {
      border: 1px solid #a4afb7; }
  .elementor-panel .elementor-panel-scheme-color-system-item {
    height: 20px;
    -webkit-box-flex: 1;
        -ms-flex-positive: 1;
            flex-grow: 1; }
  .elementor-panel #elementor-panel-schemes-disabled a {
    color: #39b54a; }
    .elementor-panel #elementor-panel-schemes-disabled a:hover {
      text-decoration: underline; }
  .elementor-panel #elementor-panel-schemes-disabled .elementor-nerd-box-icon {
    margin-top: 20px; }
  .elementor-panel #elementor-panel-page-menu {
    padding: 25px 15px; }
  .elementor-panel .elementor-panel-menu-group-title {
    text-transform: uppercase;
    font-size: 11px; }
  .elementor-panel .elementor-panel-menu-items {
    margin: 15px 0 25px;
    -webkit-border-radius: 5px;
            border-radius: 5px;
    overflow: hidden; }
  .elementor-panel .elementor-panel-menu-item {
    display: table;
    width: 100%;
    height: 40px;
    cursor: pointer;
    margin-bottom: 1px;
    background-color: #fff; }
    .elementor-panel .elementor-panel-menu-item:hover {
      background-color: rgba(255, 255, 255, 0.8); }
    .elementor-panel .elementor-panel-menu-item > * {
      display: table-cell;
      vertical-align: middle; }
    .elementor-panel .elementor-panel-menu-item-icon {
      text-align: center;
      width: 50px;
      color: #a4afb7;
      font-size: 19px; }
      .elementor-panel .elementor-panel-menu-item-icon .eicon-editor-external-link {
        font-size: 18px; }
    .elementor-panel .elementor-panel-menu-item-title {
      font-weight: 500; }
      .elementor-panel .elementor-panel-menu-item-title > span {
        color: #39b54a; }
    .elementor-panel .elementor-panel-menu-item a {
      color: #6d7882; }
    .elementor-panel .elementor-panel-menu-item-exit-to-dashboard {
      background-color: #0085ba;
      color: #fff;
      text-transform: uppercase;
      font-size: 12px; }
      .elementor-panel .elementor-panel-menu-item-exit-to-dashboard:hover {
        background-color: #0073a1; }
      .elementor-panel .elementor-panel-menu-item-exit-to-dashboard .elementor-panel-menu-item-title,
      .elementor-panel .elementor-panel-menu-item-exit-to-dashboard .elementor-panel-menu-item-icon {
        color: #fff; }
    .elementor-panel .elementor-panel-menu-item-settings-additional-settings {
      background-color: #f1f3f5; }
  .elementor-panel .elementor-control.elementor-control-clear_page {
    background-color: transparent; }
    .elementor-panel .elementor-control.elementor-control-clear_page .elementor-control-raw-html {
      display: -webkit-box;
      display: -ms-flexbox;
      display: flex;
      -webkit-box-align: center;
          -ms-flex-align: center;
              align-items: center;
      -webkit-box-pack: justify;
          -ms-flex-pack: justify;
              justify-content: space-between; }
  .elementor-panel .elementor-panel-navigation {
    background-color: #ffffff;
    -webkit-box-shadow: 0 0 8px rgba(0, 0, 0, 0.1);
            box-shadow: 0 0 8px rgba(0, 0, 0, 0.1);
    display: table;
    table-layout: fixed;
    width: 100%; }
    .elementor-panel .elementor-panel-navigation .elementor-panel-navigation-tab {
      display: table-cell; }
      .elementor-panel .elementor-panel-navigation .elementor-panel-navigation-tab.elementor-active {
        background-image: -webkit-gradient(linear, left top, left bottom, from(#f1f3f5), to(#fff));
        background-image: -webkit-linear-gradient(top, #f1f3f5, #fff);
        background-image: -o-linear-gradient(top, #f1f3f5, #fff);
        background-image: linear-gradient(to bottom, #f1f3f5, #fff);
        border-bottom: 3px solid #93003c; }
      .elementor-panel .elementor-panel-navigation .elementor-panel-navigation-tab a {
        display: block;
        text-align: center;
        padding: 12px 0 8px;
        font-size: 10px;
        color: #6d7882; }
        .elementor-panel .elementor-panel-navigation .elementor-panel-navigation-tab a:before {
          font-family: eicons;
          font-size: 16px;
          display: block;
          margin-bottom: 6px; }
  .elementor-panel .elementor-tab-control-content a:before {
    content: '\e92c'; }
  .elementor-panel .elementor-tab-control-style a:before {
    content: '\e921'; }
  .elementor-panel .elementor-tab-control-advanced a:before, .elementor-panel .elementor-tab-control-settings a:before, .elementor-panel .elementor-tab-control-general_style a:before {
    content: '\e916'; }
  .elementor-panel .elementor-tab-control-responsive a:before {
    content: '\e885'; }
  .elementor-panel .elementor-tab-control-layout a:before, .elementor-panel .elementor-tab-control-column a:before {
    content: '\e899'; }
  .elementor-panel .elementor-tab-control-lightbox a:before {
    content: '\e922'; }
  .elementor-panel #elementor-panel__editor__help {
    padding: 50px 25px;
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center;
    -webkit-box-pack: center;
        -ms-flex-pack: center;
            justify-content: center; }
    .elementor-panel #elementor-panel__editor__help__link {
      display: -webkit-inline-box;
      display: -ms-inline-flexbox;
      display: inline-flex;
      -webkit-box-align: center;
          -ms-flex-align: center;
              align-items: center;
      -webkit-box-pack: center;
          -ms-flex-pack: center;
              justify-content: center;
      color: #6d7882;
      font-size: 12px;
      font-weight: 500;
      -webkit-transition: all 0.3s;
      -o-transition: all 0.3s;
      transition: all 0.3s; }
      .elementor-panel #elementor-panel__editor__help__link i {
        padding: 0 5px;
        color: #a4afb7;
        font-size: 18px;
        position: relative; }
        .elementor-panel #elementor-panel__editor__help__link i:after {
          content: '';
          position: absolute;
          height: 13px;
          width: 13px;
          top: 3px;
          bottom: 0;
          right: 8px;
          left: 0;
          -webkit-border-radius: 50%;
                  border-radius: 50%;
          z-index: -1; }
      .elementor-panel #elementor-panel__editor__help__link:hover {
        color: #495157; }
        .elementor-panel #elementor-panel__editor__help__link:hover i {
          color: #71d7f7; }
          .elementor-panel #elementor-panel__editor__help__link:hover i:before {
            content: '\e941'; }
          .elementor-panel #elementor-panel__editor__help__link:hover i:after {
            background: #fff; }
  .elementor-panel #elementor-panel-footer {
    position: absolute;
    bottom: 0;
    left: 0;
    right: 0;
    height: 40px;
    background-color: #495157; }
  .elementor-panel #elementor-panel-footer-tools {
    display: table;
    table-layout: fixed;
    width: 100%;
    height: 100%; }
  .elementor-panel .elementor-panel-footer-tool {
    display: table-cell;
    vertical-align: middle;
    text-align: center;
    cursor: pointer;
    color: #a4afb7;
    -webkit-transition: all 0.3s;
    -o-transition: all 0.3s;
    transition: all 0.3s; }
    .elementor-panel .elementor-panel-footer-tool #elementor-panel-saver-button-update {
      border-left: 1px solid #2d8739;
      -webkit-border-radius: 0 3px 3px 0;
              border-radius: 0 3px 3px 0; }
      .elementor-panel .elementor-panel-footer-tool #elementor-panel-saver-button-update i {
        margin-left: 5px; }
    .elementor-panel .elementor-panel-footer-tool #elementor-panel-saver-button-save-options {
      float: right;
      -webkit-border-radius: 3px 0 0 3px;
              border-radius: 3px 0 0 3px; }
      .elementor-panel .elementor-panel-footer-tool #elementor-panel-saver-button-save-options i {
        margin: auto; }
    .elementor-panel .elementor-panel-footer-tool.elementor-open {
      color: #fff; }
    .elementor-panel .elementor-panel-footer-tool:not(.elementor-open):hover {
      color: #d5dadf; }
    .elementor-panel .elementor-panel-footer-tool:not(.elementor-open) .elementor-panel-footer-sub-menu-wrapper {
      display: none; }
  .elementor-panel .elementor-panel-footer-sub-menu-wrapper {
    position: absolute;
    bottom: 100%;
    left: 0;
    width: 100%;
    background-color: #556068;
    padding: 10px;
    -webkit-box-shadow: -2px -5px 8px rgba(0, 0, 0, 0.1);
            box-shadow: -2px -5px 8px rgba(0, 0, 0, 0.1);
    cursor: default;
    z-index: 10000; }
  .elementor-panel .elementor-panel-footer-sub-menu {
    -webkit-border-radius: 5px;
            border-radius: 5px;
    overflow: hidden; }
  .elementor-panel .elementor-panel-footer-sub-menu-item {
    background-color: #495157;
    display: table;
    table-layout: fixed;
    width: 100%;
    cursor: pointer; }
    .elementor-panel .elementor-panel-footer-sub-menu-item.elementor-disabled .elementor-icon,
    .elementor-panel .elementor-panel-footer-sub-menu-item.elementor-disabled .elementor-title {
      color: #6d7882; }
    .elementor-panel .elementor-panel-footer-sub-menu-item:not(:last-child) {
      margin-bottom: 1px; }
    .elementor-panel .elementor-panel-footer-sub-menu-item:hover {
      background-color: rgba(0, 0, 0, 0.2); }
    .elementor-panel .elementor-panel-footer-sub-menu-item.active {
      background-color: rgba(0, 0, 0, 0.3); }
    .elementor-panel .elementor-panel-footer-sub-menu-item > * {
      display: table-cell;
      height: 40px;
      vertical-align: middle; }
    .elementor-panel .elementor-panel-footer-sub-menu-item .elementor-icon {
      width: 40px;
      color: #a4afb7; }
    .elementor-panel .elementor-panel-footer-sub-menu-item .elementor-title {
      text-align: right;
      color: #d5dadf; }
    .elementor-panel .elementor-panel-footer-sub-menu-item .elementor-description {
      width: 95px;
      text-align: right;
      font-size: 11px;
      font-style: italic;
      color: #a4afb7; }
  .elementor-panel #elementor-panel-footer-help-title {
    text-align: right;
    padding: 10px 0;
    color: #d5dadf; }
  .elementor-panel #elementor-panel-footer-responsive > i {
    display: block;
    height: 100%;
    line-height: 40px; }
  .elementor-panel #elementor-panel-footer-saver-publish {
    width: 80px; }
    .elementor-panel #elementor-panel-footer-saver-publish .elementor-button-state i {
      margin-left: 0; }
    .elementor-panel #elementor-panel-footer-saver-publish .elementor-button-state #elementor-panel-saver-button-publish-label {
      display: none; }
  .elementor-panel #elementor-panel-footer-saver-options {
    width: 35px;
    border-right: 1px solid #495157; }
    .elementor-panel #elementor-panel-footer-saver-options .elementor-last-edited-wrapper {
      font-size: 11px;
      font-style: italic;
      color: #a4afb7;
      padding: 5px 0 15px; }
      .elementor-panel #elementor-panel-footer-saver-options .elementor-last-edited-wrapper:not(.elementor-state-active) .elementor-state-icon {
        display: none; }
      .elementor-panel #elementor-panel-footer-saver-options .elementor-last-edited-wrapper time {
        border-bottom: 1px dotted transparent;
        -webkit-transition: all ease-in-out .3s;
        -o-transition: all ease-in-out .3s;
        transition: all ease-in-out .3s;
        cursor: pointer; }
        .elementor-panel #elementor-panel-footer-saver-options .elementor-last-edited-wrapper time:hover {
          border-bottom-color: inherit; }
  .elementor-panel .elementor-disabled {
    cursor: default; }
  .elementor-panel #elementor-panel-saver-button-preview a {
    color: #a4afb7; }
  .elementor-panel #elementor-panel-saver-button-publish, .elementor-panel #elementor-panel-saver-button-save-options {
    font-size: 11px;
    text-transform: uppercase;
    height: 26px; }
    .elementor-panel #elementor-panel-saver-button-publish.elementor-disabled, .elementor-panel #elementor-panel-saver-button-save-options.elementor-disabled {
      background-color: #556068;
      color: #a4afb7; }
  .elementor-panel #elementor-panel-saver-button-publish {
    width: 100%;
    -webkit-border-radius: 0 3px 3px 0;
            border-radius: 0 3px 3px 0; }
  .elementor-panel #elementor-panel-saver-button-save-options {
    width: 25px; }

#elementor-panel-elements-navigation .elementor-panel-navigation-tab {
  text-align: center;
  padding: 10px 0;
  font-size: 11px;
  text-transform: uppercase;
  cursor: pointer; }

#elementor-panel-elements {
  overflow: hidden; }

#elementor-panel-state-loading {
  display: none; }
  body.elementor-panel-loading #elementor-panel-state-loading {
    position: absolute;
    top: 0;
    left: 0;
    height: 100%;
    width: 100%;
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center;
    -webkit-box-pack: center;
        -ms-flex-pack: center;
            justify-content: center;
    background-color: rgba(255, 255, 255, 0.5);
    z-index: 2; }
  #elementor-panel-state-loading .eicon-loading {
    font-size: 25px;
    color: #71d7f7; }

#elementor-panel-elements-search-area {
  position: -webkit-sticky;
  position: sticky;
  top: 0;
  padding: 10px;
  background-color: #e6e9ec;
  z-index: 1; }

#elementor-panel-elements-search-wrapper {
  position: relative; }

#elementor-panel-elements-search-input {
  background-color: rgba(255, 255, 255, 0.7);
  font-size: 11px;
  padding: 10px 29px 10px 10px;
  font-style: italic;
  color: #a4afb7;
  border: none;
  -webkit-transition: all 1s;
  -o-transition: all 1s;
  transition: all 1s;
  -webkit-border-radius: 3px;
          border-radius: 3px;
  appearance: none;
  -webkit-appearance: none;
  -moz-appearance: none; }
  #elementor-panel-elements-search-input + i {
    position: absolute;
    right: 10px;
    top: 50%;
    color: #a4afb7;
    -webkit-transform: translateY(-50%);
        -ms-transform: translateY(-50%);
            transform: translateY(-50%); }
  #elementor-panel-elements-search-input:focus {
    background-color: white;
    padding-left: 15px; }

.elementor-panel .elementor-element {
  -webkit-border-radius: 3px;
          border-radius: 3px;
  background-color: #fff;
  cursor: move;
  position: relative; }
  .elementor-panel .elementor-element-wrapper {
    text-align: center;
    -webkit-box-sizing: border-box;
            box-sizing: border-box; }
  .elementor-panel .elementor-element--promotion .elementor-element {
    cursor: pointer;
    -webkit-user-select: none;
       -moz-user-select: none;
        -ms-user-select: none;
            user-select: none; }
  .elementor-panel .elementor-element .icon,
  .elementor-panel .elementor-element .title {
    color: #556068;
    -webkit-transition: all 0.3s;
    -o-transition: all 0.3s;
    transition: all 0.3s; }
  .elementor-panel .elementor-element:hover {
    -webkit-box-shadow: 0 2px 6px rgba(0, 0, 0, 0.2);
            box-shadow: 0 2px 6px rgba(0, 0, 0, 0.2); }
    .elementor-panel .elementor-element:hover .icon, .elementor-panel .elementor-element:hover .title {
      color: #93003c; }
  .elementor-panel .elementor-element .icon {
    font-size: 28px;
    padding-top: 15px; }
  .elementor-panel .elementor-element .elementor-element-title-wrapper {
    display: table;
    width: 100%; }
  .elementor-panel .elementor-element .title {
    font-size: 11px;
    display: table-cell;
    vertical-align: middle;
    height: 40px; }
  .elementor-panel .elementor-element > .eicon-lock {
    position: absolute;
    top: 5px;
    left: 5px;
    color: #e6e9ec; }

#elementor-element--promotion__dialog {
  position: absolute;
  width: 300px;
  z-index: 1;
  background-color: #fff;
  -webkit-box-shadow: 0 2px 15px rgba(0, 0, 0, 0.3);
          box-shadow: 0 2px 15px rgba(0, 0, 0, 0.3);
  -webkit-border-radius: 3px;
          border-radius: 3px; }
  #elementor-element--promotion__dialog:after {
    content: '';
    position: absolute;
    top: 15px;
    left: 100%;
    -webkit-transform: scaleY(0.7);
        -ms-transform: scaleY(0.7);
            transform: scaleY(0.7);
    border: 10px solid transparent;
    border-left-color: #fff; }
  #elementor-element--promotion__dialog__title {
    font-size: 14px; }
  #elementor-element--promotion__dialog .dialog-header {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    padding: 20px;
    color: #495157;
    border-bottom: 1px solid #e6e9ec;
    font-weight: 500; }
    #elementor-element--promotion__dialog .dialog-header i {
      color: #a4afb7; }
    #elementor-element--promotion__dialog .dialog-header .eicon-pro-icon {
      -webkit-box-flex: 1;
          -ms-flex-positive: 1;
              flex-grow: 1;
      margin-right: 10px;
      font-size: 14px; }
    #elementor-element--promotion__dialog .dialog-header .eicon-close {
      cursor: pointer; }
  #elementor-element--promotion__dialog .dialog-message {
    padding: 20px; }
  #elementor-element--promotion__dialog .dialog-buttons-wrapper {
    padding: 0 20px 20px 20px; }
  #elementor-element--promotion__dialog .dialog-button {
    width: 100%;
    padding: 6.5px;
    font-size: 12px; }
    #elementor-element--promotion__dialog .dialog-button::-moz-focus-inner {
      border: 0; }

#elementor-panel-inner {
  position: relative;
  height: 100%;
  -webkit-box-shadow: 0 0 5px 0 rgba(0, 0, 0, 0.2);
          box-shadow: 0 0 5px 0 rgba(0, 0, 0, 0.2); }

#elementor-panel-content-wrapper {
  position: absolute;
  bottom: 40px;
  top: 40px;
  left: 0;
  width: 100%; }

.elementor-panel-container {
  clear: both;
  padding-left: 15px;
  padding-right: 15px; }

.media-modal.wp-core-ui input {
  width: auto; }

.media-modal.wp-core-ui select {
  width: initial; }

.media-modal.wp-core-ui fieldset {
  padding: 0;
  border: 0; }

.media-modal.wp-core-ui .wp-clearfix::after {
  content: '';
  display: table;
  clear: both; }

.media-modal.wp-core-ui .e-wp-media-elements-removed {
  /* Hack to change the media button selection text, because for some reason the text gets changed when switching tabs. */ }
  .media-modal.wp-core-ui .e-wp-media-elements-removed .embed-link-settings,
  .media-modal.wp-core-ui .e-wp-media-elements-removed .embed-media-settings > :not(.wp-clearfix):not(.alt-text):not(#alt-text-description) {
    display: none; }
  .media-modal.wp-core-ui .e-wp-media-elements-removed #embed-url-field {
    width: 70%; }
  .media-modal.wp-core-ui .e-wp-media-elements-removed .media-embed .thumbnail {
    margin-top: 20px; }
    .media-modal.wp-core-ui .e-wp-media-elements-removed .media-embed .thumbnail,
    .media-modal.wp-core-ui .e-wp-media-elements-removed .media-embed .thumbnail img {
      max-height: initial; }
    .media-modal.wp-core-ui .e-wp-media-elements-removed .media-embed .thumbnail::after {
      -webkit-box-shadow: none;
              box-shadow: none; }
  .media-modal.wp-core-ui .e-wp-media-elements-removed .media-button-select {
    font-size: 0; }
    .media-modal.wp-core-ui .e-wp-media-elements-removed .media-button-select::before {
      content: var(--button-text);
      font-size: 13px; }

#elementor-panel-get-pro-elements .elementor-nerd-box-message {
  margin-top: 10px; }

#elementor-panel-get-pro-elements .elementor-nerd-box-icon {
  margin-top: 20px; }

.elementor-control {
  --control-title-size: 12px;
  background-color: #fff;
  position: relative;
  padding: 0 20px 15px; }
  .elementor-control a {
    font-weight: 500;
    text-decoration: none;
    border-bottom: 1px dotted transparent;
    -webkit-transition: all ease-in-out .3s;
    -o-transition: all ease-in-out .3s;
    transition: all ease-in-out .3s; }
    .elementor-control a:hover {
      border-bottom-color: inherit; }
    .elementor-control a.elementor-responsive-switcher {
      border-bottom: 0; }
  .elementor-control .elementor-control-content {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-orient: vertical;
    -webkit-box-direction: normal;
        -ms-flex-direction: column;
            flex-direction: column; }
  .elementor-control .elementor-control-title {
    font-size: var(--control-title-size);
    line-height: 1;
    margin-left: 5px; }
  .elementor-control .elementor-control-spinner {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center; }
  .elementor-control.elementor-control-type-divider {
    padding: 0;
    background-color: transparent; }
    .elementor-control.elementor-control-type-divider .elementor-control-content {
      border-width: 0;
      border-color: #e6e9ec;
      border-style: solid;
      border-top-width: 1px;
      background-color: #ffffff;
      height: 15px; }
  .elementor-control.elementor-control-separator-default:not(.elementor-control-type-divider).elementor-control-wp {
    margin-top: 15px; }
    .elementor-control.elementor-control-separator-default:not(.elementor-control-type-divider).elementor-control-wp:before {
      content: '';
      height: 1px;
      display: block;
      margin-bottom: 15px;
      background-color: transparent; }
  .elementor-control.elementor-control-separator-before {
    padding-top: 15px; }
    .elementor-control.elementor-control-separator-before:before {
      content: '';
      position: absolute;
      height: 1px;
      width: 100%;
      top: 0;
      left: 0;
      background-color: #e6e9ec; }
  .elementor-control.elementor-control-separator-after:after {
    content: '';
    position: absolute;
    height: 1px;
    width: 100%;
    bottom: 0;
    left: 0;
    background-color: #e6e9ec; }
  .elementor-control.elementor-control-separator-after + .elementor-control-type-tabs + .elementor-control-separator-default, .elementor-control.elementor-control-separator-after:not(.elementor-hidden-control) + .elementor-control-separator-default {
    padding-top: 15px; }
  .elementor-control.elementor-control-deprecated {
    color: #b01b1b; }
    .elementor-control.elementor-control-deprecated .elementor-control-field-description {
      color: #b01b1b; }
  .elementor-control.elementor-control-hidden-label > * > .elementor-control-title, .elementor-control.elementor-control-hidden-label > * > * > .elementor-control-title {
    display: none; }
  .elementor-control.elementor-hidden-control {
    display: none; }
  .elementor-control.elementor-control-type-heading .elementor-control-title {
    font-weight: bold;
    margin: 0; }
  body:not(.elementor-device-widescreen) .elementor-control.elementor-control-responsive-widescreen {
    display: none; }
  body:not(.elementor-device-desktop) .elementor-control.elementor-control-responsive-desktop {
    display: none; }
  body:not(.elementor-device-laptop) .elementor-control.elementor-control-responsive-laptop {
    display: none; }
  body:not(.elementor-device-tablet_extra) .elementor-control.elementor-control-responsive-tablet_extra {
    display: none; }
  body:not(.elementor-device-tablet) .elementor-control.elementor-control-responsive-tablet {
    display: none; }
  body:not(.elementor-device-mobile_extra) .elementor-control.elementor-control-responsive-mobile_extra {
    display: none; }
  body:not(.elementor-device-mobile) .elementor-control.elementor-control-responsive-mobile {
    display: none; }
  .elementor-control.elementor-control-type-select .elementor-control-input-wrapper {
    position: relative; }
    .elementor-control.elementor-control-type-select .elementor-control-input-wrapper select {
      appearance: none;
      -webkit-appearance: none;
      -moz-appearance: none;
      font-size: 12px;
      font-family: inherit;
      font-weight: inherit;
      font-style: inherit;
      text-transform: inherit;
      letter-spacing: inherit;
      line-height: inherit;
      -ms-flex-preferred-size: 100%;
          flex-basis: 100%;
      padding-right: 5px;
      padding-left: 20px;
      cursor: pointer; }
      .elementor-control.elementor-control-type-select .elementor-control-input-wrapper select.e-select-placeholder {
        color: #a4afb7; }
    .elementor-control.elementor-control-type-select .elementor-control-input-wrapper option.e-option-placeholder {
      display: none; }
    .elementor-control.elementor-control-type-select .elementor-control-input-wrapper:after {
      font-family: eicons;
      content: '\e8ad';
      font-size: 12px;
      position: absolute;
      top: 50%;
      -webkit-transform: translateY(-50%);
          -ms-transform: translateY(-50%);
              transform: translateY(-50%);
      left: 5px;
      pointer-events: none; }
  .elementor-control-custom_css_pro .elementor-nerd-box-message, .elementor-control-custom_attributes_pro .elementor-nerd-box-message {
    margin-top: 5px; }
  .elementor-control.elementor-control-custom_css_title {
    font-size: 12px; }

.elementor-control.elementor-open .elementor-panel-heading-toggle .eicon:before,
.elementor-panel-scheme-item.elementor-open .elementor-panel-heading-toggle .eicon:before {
  content: '\e92a'; }

.elementor-control:not(.elementor-open) .elementor-panel-heading-toggle .eicon:before,
.elementor-panel-scheme-item:not(.elementor-open) .elementor-panel-heading-toggle .eicon:before {
  content: ""; }

.elementor-panel-heading {
  display: table;
  table-layout: fixed;
  height: 40px;
  padding: 0 20px;
  width: 100%;
  border-bottom: 1px solid #e6e9ec;
  cursor: pointer; }
  .elementor-panel-heading > * {
    display: table-cell;
    vertical-align: middle; }
  .elementor-panel-heading-toggle {
    width: 20px;
    color: #495157; }
  .elementor-panel-heading-title {
    color: #495157;
    font-weight: bold; }

.elementor-control-wp {
  line-height: 1.5; }
  .elementor-control-wp p {
    margin: 15px 0; }

.elementor-control-field {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center; }

.elementor-label-block > .elementor-control-content > .elementor-control-field {
  -ms-flex-wrap: wrap;
      flex-wrap: wrap; }
  .elementor-label-block > .elementor-control-content > .elementor-control-field > .elementor-control-input-wrapper {
    width: 100%;
    margin-top: 10px; }

.elementor-label-block.elementor-control-hidden-label:not(.elementor-control-dynamic) > .elementor-control-content > .elementor-control-field > .elementor-control-input-wrapper {
  margin-top: 0; }

.elementor-label-block.elementor-control-hidden-label.elementor-label-block > .elementor-control-content > .elementor-control-field > .elementor-control-input-wrapper {
  margin-top: 0; }

.elementor-label-inline > .elementor-control-content > .elementor-control-field > .elementor-control-title {
  -ms-flex-negative: 0;
      flex-shrink: 0; }

.elementor-label-inline > .elementor-control-content > .elementor-control-field > .elementor-control-input-wrapper {
  margin-right: auto; }

.elementor-control-field-description {
  margin-top: 10px; }

.elementor-group-control-attachment_alert .elementor-control-field-description {
  margin-top: 0; }

.elementor-required {
  color: #b01b1b; }

.elementor-units-choices {
  -webkit-box-flex: 1;
      -ms-flex-positive: 1;
          flex-grow: 1;
  text-align: left; }
  .elementor-units-choices input {
    display: none; }
    .elementor-units-choices input:not(:checked) + label {
      color: #a4afb7; }
    .elementor-units-choices input.e-units-placeholder + label {
      color: #c2cbd2;
      text-decoration: underline; }
    .elementor-units-choices input:checked + label {
      text-decoration: underline; }
  .elementor-units-choices label {
    cursor: pointer;
    padding: 0 2px;
    text-transform: uppercase;
    font-size: 9px; }

.elementor-control-start-end .eicon-h-align-left, .elementor-control-start-end .eicon-h-align-right {
  -webkit-transform: rotate(180deg);
      -ms-transform: rotate(180deg);
          transform: rotate(180deg); }

.elementor-control-responsive-switchers {
  --selected-option: 0;
  --pointer-position: var(--selected-option);
  position: relative;
  width: 2em;
  height: 2em;
  margin: calc( -2em + var(--control-title-size)) 0;
  margin-left: 5px; }
  .elementor-control-responsive-switchers__holder {
    position: absolute;
    width: 100%;
    top: 0;
    background-color: #fff;
    -webkit-border-radius: 3px;
            border-radius: 3px;
    -webkit-transition: 0.15s;
    -o-transition: 0.15s;
    transition: 0.15s;
    border: 1px transparent solid; }
  .elementor-control-responsive-switchers.elementor-responsive-switchers-open {
    z-index: 11000; }
    .elementor-control-responsive-switchers.elementor-responsive-switchers-open .elementor-responsive-switcher {
      height: 2em;
      -webkit-transform: scale(1);
          -ms-transform: scale(1);
              transform: scale(1);
      opacity: 1; }
      .elementor-control-responsive-switchers.elementor-responsive-switchers-open .elementor-responsive-switcher:hover {
        color: #71d7f7; }
    .elementor-control-responsive-switchers.elementor-responsive-switchers-open .elementor-control-responsive-switchers__holder {
      top: calc(-1 * var(--selected-option) * 2em);
      -webkit-box-shadow: 0 0 3px rgba(0, 0, 0, 0.2);
              box-shadow: 0 0 3px rgba(0, 0, 0, 0.2); }

.elementor-responsive-switcher {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  -webkit-box-pack: center;
      -ms-flex-pack: center;
          justify-content: center;
  position: relative;
  z-index: 2;
  cursor: pointer;
  height: 0;
  -webkit-transform: scale(0);
      -ms-transform: scale(0);
          transform: scale(0);
  opacity: 0;
  -webkit-transition: 0.15s;
  -o-transition: 0.15s;
  transition: 0.15s;
  font-size: 12px; }

a.elementor-responsive-switcher {
  color: #a4afb7; }
  a.elementor-responsive-switcher:hover {
    color: #71d7f7; }

.elementor-device-widescreen .elementor-responsive-switcher.elementor-responsive-switcher-widescreen {
  height: 2em;
  -webkit-transform: scale(1);
      -ms-transform: scale(1);
          transform: scale(1);
  opacity: 1; }

.elementor-device-widescreen .elementor-responsive-switchers-open:not(:hover) .elementor-responsive-switcher.elementor-responsive-switcher-widescreen {
  color: #71d7f7; }

.elementor-device-desktop .elementor-responsive-switcher.elementor-responsive-switcher-desktop {
  height: 2em;
  -webkit-transform: scale(1);
      -ms-transform: scale(1);
          transform: scale(1);
  opacity: 1; }

.elementor-device-desktop .elementor-responsive-switchers-open:not(:hover) .elementor-responsive-switcher.elementor-responsive-switcher-desktop {
  color: #71d7f7; }

.elementor-device-laptop .elementor-responsive-switcher.elementor-responsive-switcher-laptop {
  height: 2em;
  -webkit-transform: scale(1);
      -ms-transform: scale(1);
          transform: scale(1);
  opacity: 1; }

.elementor-device-laptop .elementor-responsive-switchers-open:not(:hover) .elementor-responsive-switcher.elementor-responsive-switcher-laptop {
  color: #71d7f7; }

.elementor-device-tablet_extra .elementor-responsive-switcher.elementor-responsive-switcher-tablet_extra {
  height: 2em;
  -webkit-transform: scale(1);
      -ms-transform: scale(1);
          transform: scale(1);
  opacity: 1; }

.elementor-device-tablet_extra .elementor-responsive-switchers-open:not(:hover) .elementor-responsive-switcher.elementor-responsive-switcher-tablet_extra {
  color: #71d7f7; }

.elementor-device-tablet .elementor-responsive-switcher.elementor-responsive-switcher-tablet {
  height: 2em;
  -webkit-transform: scale(1);
      -ms-transform: scale(1);
          transform: scale(1);
  opacity: 1; }

.elementor-device-tablet .elementor-responsive-switchers-open:not(:hover) .elementor-responsive-switcher.elementor-responsive-switcher-tablet {
  color: #71d7f7; }

.elementor-device-mobile_extra .elementor-responsive-switcher.elementor-responsive-switcher-mobile_extra {
  height: 2em;
  -webkit-transform: scale(1);
      -ms-transform: scale(1);
          transform: scale(1);
  opacity: 1; }

.elementor-device-mobile_extra .elementor-responsive-switchers-open:not(:hover) .elementor-responsive-switcher.elementor-responsive-switcher-mobile_extra {
  color: #71d7f7; }

.elementor-device-mobile .elementor-responsive-switcher.elementor-responsive-switcher-mobile {
  height: 2em;
  -webkit-transform: scale(1);
      -ms-transform: scale(1);
          transform: scale(1);
  opacity: 1; }

.elementor-device-mobile .elementor-responsive-switchers-open:not(:hover) .elementor-responsive-switcher.elementor-responsive-switcher-mobile {
  color: #71d7f7; }

.elementor-update-preview {
  margin: 15px 15px 0;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center; }

.elementor-update-preview-button-wrapper {
  -webkit-box-flex: 1;
      -ms-flex-positive: 1;
          flex-grow: 1;
  text-align: left; }

.elementor-update-preview-button {
  padding: 8px 15px;
  text-transform: uppercase; }

.elementor-control-direction-ltr input,
.elementor-control-direction-ltr textarea {
  direction: ltr; }

.elementor-control-direction-rtl input,
.elementor-control-direction-rtl textarea {
  direction: rtl; }

.elementor-control-type-button .elementor-control-input-wrapper {
  text-align: left; }

.elementor-control-type-button .elementor-button {
  width: auto;
  height: 26px; }

.elementor-control-type-choose.elementor-label-block .elementor-choices {
  width: 100%; }

.elementor-choices {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  height: 27px;
  line-height: 27px;
  text-align: center;
  border-spacing: 1px;
  -webkit-border-radius: 3px;
          border-radius: 3px;
  overflow: hidden; }
  .elementor-choices .elementor-choices-label {
    border-top: 1px solid #d5dadf;
    border-bottom: 1px solid #d5dadf;
    border-right: 1px solid #d5dadf;
    border-left: none;
    font-size: 12px;
    -webkit-transition: all .5s;
    -o-transition: all .5s;
    transition: all .5s;
    cursor: pointer;
    overflow: hidden; }
    .elementor-choices .elementor-choices-label:nth-child(2) {
      -webkit-border-top-right-radius: 3px;
              border-top-right-radius: 3px;
      -webkit-border-bottom-right-radius: 3px;
              border-bottom-right-radius: 3px; }
    .elementor-choices .elementor-choices-label:last-child {
      border-left: 1px solid #d5dadf;
      -webkit-border-top-left-radius: 3px;
              border-top-left-radius: 3px;
      -webkit-border-bottom-left-radius: 3px;
              border-bottom-left-radius: 3px; }
  .elementor-choices input {
    display: none; }
    .elementor-choices input.e-choose-placeholder + .elementor-choices-label {
      color: #ffffff;
      background-color: #c2cbd2;
      border-color: #c2cbd2; }
    .elementor-choices input:checked + .elementor-choices-label {
      color: #fff;
      background-color: #a4afb7;
      border-color: #a4afb7; }

.elementor-label-inline .elementor-choices {
  -webkit-box-pack: end;
      -ms-flex-pack: end;
          justify-content: flex-end; }

.rtl .elementor-control-type-choose[class*="elementor-control-text_align"] .elementor-choices, .rtl .elementor-control-type-choose[class*="elementor-control-align"] .elementor-choices, .rtl .elementor-control-type-choose[class*="elementor-control-position"] .elementor-choices {
  -webkit-box-orient: horizontal;
  -webkit-box-direction: reverse;
      -ms-flex-direction: row-reverse;
          flex-direction: row-reverse; }
  .rtl .elementor-control-type-choose[class*="elementor-control-text_align"] .elementor-choices .elementor-choices-label:nth-child(2), .rtl .elementor-control-type-choose[class*="elementor-control-align"] .elementor-choices .elementor-choices-label:nth-child(2), .rtl .elementor-control-type-choose[class*="elementor-control-position"] .elementor-choices .elementor-choices-label:nth-child(2) {
    border-left: 1px solid #d5dadf;
    -webkit-border-radius: 3px 0 0 3px;
            border-radius: 3px 0 0 3px; }
  .rtl .elementor-control-type-choose[class*="elementor-control-text_align"] .elementor-choices .elementor-choices-label:last-child, .rtl .elementor-control-type-choose[class*="elementor-control-align"] .elementor-choices .elementor-choices-label:last-child, .rtl .elementor-control-type-choose[class*="elementor-control-position"] .elementor-choices .elementor-choices-label:last-child {
    border-left: none;
    -webkit-border-radius: 0 3px 3px 0;
            border-radius: 0 3px 3px 0; }

.elementor-control-type-color.e-control-global .e-global__popover-toggle ~ .pickr {
  -webkit-border-radius: 3px 0 0 3px;
          border-radius: 3px 0 0 3px;
  -ms-flex-negative: 0;
      flex-shrink: 0; }

.elementor-control-type-color .elementor-control-title {
  -webkit-box-flex: 1;
      -ms-flex-positive: 1;
          flex-grow: 1; }

.elementor-control-type-color .elementor-control-input-wrapper {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: end;
      -ms-flex-pack: end;
          justify-content: flex-end; }

.elementor-control-type-color .elementor-control-dynamic-switcher {
  border-right-width: 0;
  -webkit-border-radius: 3px 0 0 3px;
          border-radius: 3px 0 0 3px; }

.elementor-control-type-color.elementor-control-dynamic .pickr {
  -webkit-border-radius: 0 3px 3px 0;
          border-radius: 0 3px 3px 0; }

.elementor-group-control-css-filter .elementor-slider {
  height: 6px;
  -webkit-box-shadow: 0 0 1px 1px inset rgba(0, 0, 0, 0.2);
          box-shadow: 0 0 1px 1px inset rgba(0, 0, 0, 0.2); }

.elementor-group-control-css-filter .elementor-control-content > .elementor-control-field > .elementor-control-input-wrapper {
  margin-top: 0;
  margin-bottom: 5px; }

.elementor-group-control-blur .elementor-slider {
  background: url("../images/blur.png");
  -webkit-background-size: cover;
          background-size: cover;
  background-position: center; }

.elementor-group-control-contrast .elementor-slider {
  background: url("../images/contrast.png");
  -webkit-background-size: 100% 100%;
          background-size: 100% 100%; }

.elementor-group-control-hue .elementor-slider {
  background-image: -webkit-gradient(linear, left top, right top, from(red), color-stop(orange), color-stop(yellow), color-stop(greenyellow), color-stop(limegreen), color-stop(deepskyblue), color-stop(blue), color-stop(95%, darkviolet));
  background-image: -webkit-linear-gradient(left, red, orange, yellow, greenyellow, limegreen, deepskyblue, blue, darkviolet 95%);
  background-image: -o-linear-gradient(left, red, orange, yellow, greenyellow, limegreen, deepskyblue, blue, darkviolet 95%);
  background-image: linear-gradient(to right, red, orange, yellow, greenyellow, limegreen, deepskyblue, blue, darkviolet 95%); }

.elementor-group-control-saturate .elementor-slider {
  background-image: -webkit-gradient(linear, left top, right top, from(gray), to(red));
  background-image: -webkit-linear-gradient(left, gray, red);
  background-image: -o-linear-gradient(left, gray, red);
  background-image: linear-gradient(to right, gray, red); }

.elementor-group-control-brightness .elementor-slider {
  background-image: -webkit-gradient(linear, left top, right top, from(black), to(white));
  background-image: -webkit-linear-gradient(left, black, white);
  background-image: -o-linear-gradient(left, black, white);
  background-image: linear-gradient(to right, black, white); }

.elementor-control-type-dimensions .elementor-control-dimensions {
  overflow: hidden; }

.elementor-control-type-dimensions li {
  float: left;
  width: 20%; }
  .elementor-control-type-dimensions li input,
  .elementor-control-type-dimensions li .elementor-link-dimensions {
    display: block;
    text-align: center;
    width: 100%;
    border-color: #d5dadf;
    height: 27px; }
  .elementor-control-type-dimensions li input {
    border-left: none;
    -webkit-border-radius: 0;
            border-radius: 0;
    padding: 4px 0; }
    .elementor-control-type-dimensions li input:focus {
      border-left: solid 1px;
      border-color: #a4afb7;
      margin-left: -1px;
      width: calc(100% + 1px); }
      .elementor-control-type-dimensions li input:focus + .elementor-control-dimension-label {
        color: #a4afb7; }
  .elementor-control-type-dimensions li .elementor-link-dimensions {
    border: 1px solid #d5dadf;
    border-left: none;
    background-color: #fff;
    padding: 0;
    outline: none;
    -webkit-border-radius: 0 3px 3px 0;
            border-radius: 0 3px 3px 0;
    cursor: pointer; }
  .elementor-control-type-dimensions li:first-child input {
    border-left: 1px solid #d5dadf;
    -webkit-border-radius: 3px 0 0 3px;
            border-radius: 3px 0 0 3px; }
    .elementor-control-type-dimensions li:first-child input:focus {
      border-color: #a4afb7;
      margin-left: 0;
      width: 100%; }

.elementor-control-type-dimensions .elementor-control-dimension-label {
  display: block;
  text-align: center;
  color: #d5dadf;
  font-size: 9px;
  text-transform: uppercase;
  padding-top: 5px; }

.elementor-control-type-dimensions .elementor-link-dimensions.unlinked {
  background-color: #fff; }
  .elementor-control-type-dimensions .elementor-link-dimensions.unlinked .elementor-linked {
    display: none; }

.elementor-control-type-dimensions .elementor-link-dimensions:not(.unlinked) {
  background-color: #a4afb7;
  border-color: #a4afb7; }
  .elementor-control-type-dimensions .elementor-link-dimensions:not(.unlinked) .elementor-unlinked {
    display: none; }

.elementor-control-type-dimensions .elementor-link-dimensions .elementor-linked {
  color: #fff; }

.elementor-control-type-icons .elementor-control-media__preview > * {
  position: absolute;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
      -ms-transform: translate(-50%, -50%);
          transform: translate(-50%, -50%); }

.elementor-control-type-icons .elementor-control-media__preview i {
  font-size: 70px;
  color: #6d7882; }

.elementor-control-type-icons .elementor-control-media__preview svg {
  height: 75%; }

.elementor-control-type-icons .elementor-control-icons--inline__svg i.eicon-upload {
  font-size: 15px; }

.elementor-control-type-gallery .elementor-control-media__content {
  border: 1px solid #d5dadf;
  -webkit-border-radius: 3px;
          border-radius: 3px; }

.elementor-control-type-gallery .elementor-control-gallery-status {
  font-size: 12px;
  height: 27px;
  padding-right: 10px;
  border-bottom: 1px solid #d5dadf;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex; }
  .elementor-control-type-gallery .elementor-control-gallery-status > * {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center; }
  .elementor-control-type-gallery .elementor-control-gallery-status-title {
    -webkit-box-flex: 1;
        -ms-flex-positive: 1;
            flex-grow: 1; }

.elementor-control-type-gallery .elementor-control-gallery-content {
  position: relative;
  overflow: hidden; }
  .elementor-control-type-gallery .elementor-control-gallery-content:not(:hover) .elementor-control-gallery-edit {
    opacity: 0; }

.elementor-control-type-gallery .elementor-control-gallery-thumbnails {
  display: grid;
  grid-template-columns: repeat(auto-fill, minmax(48px, 1fr));
  grid-gap: 10px;
  cursor: pointer;
  padding: 10px; }

.elementor-control-type-gallery .elementor-control-gallery-thumbnail {
  width: 48px;
  height: 48px;
  -webkit-background-size: cover;
          background-size: cover;
  background-position: 50% 50%; }

.elementor-control-type-gallery .elementor-control-gallery-edit {
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  right: 0;
  background-color: rgba(109, 120, 130, 0.3);
  padding: 10px;
  font-size: 11px;
  -webkit-transition: all .3s ease-in-out;
  -o-transition: all .3s ease-in-out;
  transition: all .3s ease-in-out;
  pointer-events: none;
  cursor: pointer;
  opacity: 1; }
  .elementor-control-type-gallery .elementor-control-gallery-edit span {
    position: absolute;
    top: 10px;
    left: 10px;
    width: 21px;
    height: 21px;
    background-color: rgba(255, 255, 255, 0.9);
    color: #a4afb7;
    -webkit-box-shadow: 0 0 7px 0 rgba(0, 0, 0, 0.2);
            box-shadow: 0 0 7px 0 rgba(0, 0, 0, 0.2);
    -webkit-border-radius: 3px;
            border-radius: 3px; }
    .elementor-control-type-gallery .elementor-control-gallery-edit span i {
      font-size: 11px;
      padding: 5px; }

.elementor-control-type-gallery .elementor-control-gallery-add {
  width: 48px;
  height: 48px;
  color: #fff;
  background-color: #d5dadf;
  font-size: 14px;
  -webkit-border-radius: 0;
          border-radius: 0; }
  .elementor-control-type-gallery .elementor-control-gallery-add:hover {
    background-color: #c2cbd2; }
  .elementor-control-type-gallery .elementor-control-gallery-add i {
    margin: 0;
    color: #a4afb7; }

.elementor-control-type-gallery.elementor-gallery-empty .elementor-control-gallery-clear,
.elementor-control-type-gallery.elementor-gallery-empty .elementor-control-gallery-thumbnails,
.elementor-control-type-gallery.elementor-gallery-empty .elementor-control-gallery-edit {
  display: none; }

.elementor-control-type-gallery.elementor-gallery-empty .elementor-control-gallery-content {
  padding: 10px; }

.elementor-control-type-gallery.elementor-gallery-has-images .elementor-control-gallery-add {
  display: none; }

.elementor-control-type-gallery.elementor-control-dynamic .elementor-control-gallery-clear {
  border-right: 1px solid #d5dadf; }

.elementor-control-type-gallery .elementor-control-gallery-clear {
  cursor: pointer;
  -webkit-box-pack: center;
      -ms-flex-pack: center;
          justify-content: center; }
  .elementor-control-type-gallery .elementor-control-gallery-clear:hover {
    color: #b01b1b; }

.elementor-control-type-gallery .elementor-control-dynamic-switcher {
  border: none;
  border-bottom: 1px solid #d5dadf;
  border-right: 1px solid #d5dadf;
  -webkit-border-radius: 3px 0 0 0;
          border-radius: 3px 0 0 0; }

.e-global__popover {
  width: 288px;
  z-index: 1;
  font-size: 12px;
  padding-right: 10px; }
  .e-global__popover-toggle {
    border: 1px solid #d5dadf;
    border-left: 0;
    -webkit-border-radius: 0 3px 3px 0;
            border-radius: 0 3px 3px 0;
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center;
    -webkit-box-pack: center;
        -ms-flex-pack: center;
            justify-content: center;
    cursor: pointer; }
    .e-global__popover-toggle--active i {
      color: #71d7f7; }
  .e-global__popover-container {
    -webkit-box-shadow: 0 2px 15px rgba(0, 0, 0, 0.3);
            box-shadow: 0 2px 15px rgba(0, 0, 0, 0.3);
    -webkit-border-radius: 3px;
            border-radius: 3px;
    background-color: #fff;
    padding-bottom: 5px; }
  .e-global__popover-title {
    padding: 15px 20px;
    font-weight: 500;
    color: #6d7882;
    border-bottom: 1px solid #e6e9ec;
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex; }
    .e-global__popover-title > i {
      margin-left: 5px;
      color: #d5dadf; }
    .e-global__popover-title-text {
      -webkit-box-flex: 1;
          -ms-flex-positive: 1;
              flex-grow: 1; }
  .e-global__popover-info {
    margin-left: 5px;
    display: inline-block; }
    .e-global__popover-info-tooltip {
      width: 270px;
      z-index: 1;
      background-color: rgba(0, 0, 0, 0.9);
      color: #fff;
      padding: 20px;
      -webkit-border-radius: 3px;
              border-radius: 3px; }
      .e-global__popover-info-tooltip:after {
        content: '';
        position: absolute;
        bottom: -17px;
        right: 16px;
        border: 10px solid transparent;
        border-top-color: rgba(0, 0, 0, 0.9); }
    .e-global__popover-info i {
      color: #d5dadf;
      font-size: 13px; }

.e-global__preview-items-container {
  max-height: 260px;
  overflow-y: auto;
  margin-top: 5px; }
  .e-global__preview-items-container::-webkit-scrollbar {
    width: 7px; }
  .e-global__preview-items-container::-webkit-scrollbar-thumb {
    background-color: #c2cbd2;
    -webkit-border-radius: 10px;
            border-radius: 10px; }

.e-global__manage-button {
  font-weight: 500;
  cursor: pointer; }
  .e-global__manage-button:hover i {
    color: #4ab7f4; }
  .e-global__manage-button i {
    color: #6d7882; }

.e-global__typography {
  padding: 5px 35px 5px 10px;
  white-space: nowrap;
  -o-text-overflow: ellipsis;
     text-overflow: ellipsis;
  overflow: hidden; }
  .e-global__typography.e-global__preview-item--selected:before {
    font-family: 'eicons';
    font-size: 13px;
    content: '\e90e';
    position: absolute;
    -webkit-transform: translateY(-50%);
        -ms-transform: translateY(-50%);
            transform: translateY(-50%);
    top: 50%;
    left: 12px; }

.e-global__color {
  margin: 5px auto;
  padding: 5px 20px;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center; }
  .e-global__color:first-child {
    margin-top: 5px; }
  .e-global__color:last-child {
    margin-bottom: 10px; }
  .e-global__color-preview-container {
    height: 20px;
    width: 20px;
    -webkit-border-radius: 3px;
            border-radius: 3px;
    border: 1px solid rgba(0, 0, 0, 0.1);
    margin-left: 10px;
    -ms-flex-negative: 0;
        flex-shrink: 0;
    position: relative; }
  .e-global__color-preview-color, .e-global__color-preview-transparent-bg {
    -webkit-border-radius: 3px;
            border-radius: 3px;
    height: 100%;
    width: 100%;
    position: absolute;
    top: 0;
    left: 0; }
  .e-global__color-preview-transparent-bg {
    background-image: -webkit-linear-gradient(45deg, #ddd 25%, transparent 0, transparent 75%, #ddd 0, #ddd), -webkit-linear-gradient(45deg, #ddd 25%, transparent 0, transparent 75%, #ddd 0, #ddd);
    background-image: -o-linear-gradient(45deg, #ddd 25%, transparent 0, transparent 75%, #ddd 0, #ddd), -o-linear-gradient(45deg, #ddd 25%, transparent 0, transparent 75%, #ddd 0, #ddd);
    background-image: linear-gradient(45deg, #ddd 25%, transparent 0, transparent 75%, #ddd 0, #ddd), linear-gradient(45deg, #ddd 25%, transparent 0, transparent 75%, #ddd 0, #ddd);
    -webkit-background-size: 12px 12px;
            background-size: 12px 12px;
    background-position: 0 0, 6px 6px; }
  .e-global__color-title {
    font-weight: 500;
    color: #6d7882;
    -webkit-box-flex: 1;
        -ms-flex-positive: 1;
            flex-grow: 1;
    white-space: nowrap;
    -o-text-overflow: ellipsis;
       text-overflow: ellipsis;
    overflow: hidden;
    padding-left: 10px; }
  .e-global__color-hex {
    font-size: 10px;
    font-weight: 500;
    color: #c2cbd2; }
  .e-global__color .pcr-button {
    background-color: #fff; }
  .e-global__color.e-global__preview-item--selected .e-global__color-preview-container {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-pack: center;
        -ms-flex-pack: center;
            justify-content: center;
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center;
    color: #ffffff; }
    .e-global__color.e-global__preview-item--selected .e-global__color-preview-container:before {
      font-family: 'eicons';
      font-size: 13px;
      content: '\e90e';
      text-shadow: 0px 0px 1px #000;
      z-index: 1; }

.e-global__preview-item {
  cursor: pointer;
  position: relative; }
  .e-global__preview-item:hover {
    background-color: #f1f3f5; }
    .e-global__preview-item:hover .e-global__color-hex {
      color: #a4afb7; }

.e-global__confirm-add .dialog-buttons-wrapper > .dialog-button.dialog-confirm-ok {
  color: #39b54a; }

.e-global__confirm-delete i {
  color: #b01b1b; }

.e-global__confirm-message-text i {
  color: #fcb92c; }

.e-global__confirm-input-wrapper {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  border: 1px solid #a4afb7;
  -webkit-border-radius: 3px;
          border-radius: 3px;
  margin-top: 10px;
  padding: 2px; }
  .e-global__confirm-input-wrapper input {
    font-family: Roboto, Arial, sans-serif;
    font-weight: 500;
    font-size: 12px;
    padding: 2px;
    border: 0; }

.e-control-global .elementor-control-input-wrapper {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: end;
      -ms-flex-pack: end;
          justify-content: flex-end;
  max-width: 135px;
  width: 100%; }

.e-control-global.elementor-control .elementor-control-input-wrapper {
  direction: rtl; }

.e-control-global .elementor-control-spinner {
  margin-left: 4px; }

.elementor-control-type-hidden {
  display: none !important; }

.elementor-control-type-icon .select2-selection__rendered .eicon {
  margin-right: 3px; }

.elementor-control-type-image_dimensions .elementor-control-field-description {
  margin: 0 0 15px;
  line-height: 1.4; }

.elementor-control-type-image_dimensions .elementor-control-input-wrapper {
  overflow: hidden; }

.elementor-control-type-image_dimensions .elementor-image-dimensions-field {
  width: 65px;
  float: right; }
  .elementor-control-type-image_dimensions .elementor-image-dimensions-field input:focus + .elementor-image-dimensions-field-description {
    color: #a4afb7; }

.elementor-control-type-image_dimensions .elementor-image-dimensions-separator {
  width: 20px;
  text-align: center;
  float: right;
  padding-top: 4px; }

.elementor-control-type-image_dimensions .elementor-image-dimensions-field-description {
  display: block;
  text-transform: uppercase;
  margin-top: 5px;
  color: #d5dadf;
  font-size: 9px;
  text-align: center; }

.elementor-control-type-image_dimensions .elementor-image-dimensions-apply-button {
  float: left;
  height: 27px;
  width: 65px; }

.elementor-control-media.elementor-media-empty .elementor-control-media-area .elementor-control-media__remove, .elementor-control-media.elementor-media-empty .elementor-control-media-area .elementor-control-media__content__remove {
  display: none; }

.elementor-control-media:not(.elementor-media-empty) .elementor-control-media__content__upload-button {
  display: none; }

.elementor-control-media .elementor-control-input-wrapper {
  border: 1px solid #d5dadf; }

.elementor-control-media .eicon-plus-circle {
  position: absolute;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
      -ms-transform: translate(-50%, -50%);
          transform: translate(-50%, -50%);
  color: #fff;
  font-size: 20px; }

.elementor-control-media__content__upload-button {
  background-color: #d5dadf; }

.elementor-control-media__preview {
  height: 100%;
  -webkit-background-size: cover;
          background-size: cover;
  background-position: center; }

.elementor-control-media-area {
  background-image: -webkit-linear-gradient(45deg, #ddd 25%, transparent 0, transparent 75%, #ddd 0, #ddd), -webkit-linear-gradient(45deg, #ddd 25%, transparent 0, transparent 75%, #ddd 0, #ddd);
  background-image: -o-linear-gradient(45deg, #ddd 25%, transparent 0, transparent 75%, #ddd 0, #ddd), -o-linear-gradient(45deg, #ddd 25%, transparent 0, transparent 75%, #ddd 0, #ddd);
  background-image: linear-gradient(45deg, #ddd 25%, transparent 0, transparent 75%, #ddd 0, #ddd), linear-gradient(45deg, #ddd 25%, transparent 0, transparent 75%, #ddd 0, #ddd);
  -webkit-background-size: 16px 16px;
          background-size: 16px 16px;
  background-position: 0 0, 8px 8px;
  background-color: #f6f6f6; }
  .elementor-control-media-area:not(:hover) .elementor-control-media__remove {
    display: none; }
  .elementor-control-media-area .eicon-video-camera {
    position: absolute;
    top: 50%;
    left: 50%;
    -webkit-transform: translate(-50%, -50%);
        -ms-transform: translate(-50%, -50%);
            transform: translate(-50%, -50%);
    color: rgba(255, 255, 255, 0.7);
    font-size: 21px; }

.elementor-control-media .elementor-control-media__content {
  cursor: pointer;
  overflow: hidden; }
  .elementor-control-media .elementor-control-media__content:hover:after {
    content: '';
    position: absolute;
    top: 0;
    bottom: 0;
    left: 0;
    right: 0;
    background-color: rgba(0, 0, 0, 0.2);
    pointer-events: none; }
  .elementor-control-media .elementor-control-media__content:not(:hover) .elementor-control-media__tools {
    bottom: -30px; }

.elementor-control-media__content {
  -webkit-transition: all .2s ease-in-out;
  -o-transition: all .2s ease-in-out;
  transition: all .2s ease-in-out; }

.elementor-control-media__tools {
  position: absolute;
  bottom: 0;
  left: 0;
  right: 0;
  height: 27px;
  -webkit-transition: all .2s ease-in-out;
  -o-transition: all .2s ease-in-out;
  transition: all .2s ease-in-out; }
  .elementor-control-media__tools > *:not(:first-child) {
    margin-right: 1px; }

.elementor-control-media__tool {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  -webkit-box-pack: center;
      -ms-flex-pack: center;
          justify-content: center;
  -webkit-box-flex: 1;
      -ms-flex-positive: 1;
          flex-grow: 1;
  color: #fff;
  background-color: rgba(109, 120, 130, 0.85);
  font-size: 11px;
  -webkit-transition: background .3s;
  -o-transition: background .3s;
  transition: background .3s; }
  .elementor-control-media__tool:hover {
    background-color: rgba(109, 120, 130, 0.95); }

.elementor-control-media__remove {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  -webkit-box-pack: center;
      -ms-flex-pack: center;
          justify-content: center;
  -webkit-transition: all .3s ease-in-out;
  -o-transition: all .3s ease-in-out;
  transition: all .3s ease-in-out; }

.elementor-control-media__content__remove {
  position: absolute;
  z-index: 1;
  top: 10px;
  left: 10px;
  width: 20px;
  height: 20px;
  font-size: 11px;
  color: #a4afb7;
  background-color: rgba(255, 255, 255, 0.9);
  -webkit-border-radius: 3px;
          border-radius: 3px;
  -webkit-box-shadow: 0 0 7px 0 rgba(0, 0, 0, 0.1);
          box-shadow: 0 0 7px 0 rgba(0, 0, 0, 0.1); }
  .elementor-control-media__content__remove:hover {
    background-color: white;
    -webkit-box-shadow: 0 0 5px 0 rgba(0, 0, 0, 0.4);
            box-shadow: 0 0 5px 0 rgba(0, 0, 0, 0.4); }

.elementor-control-media.elementor-media-empty .elementor-control-file-area {
  display: none; }

.elementor-control-media__file {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
      -ms-flex-pack: justify;
          justify-content: space-between;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  width: 100%;
  margin-top: 10px;
  border: 1px solid #d5dadf; }
  .elementor-control-media__file__content {
    padding-right: 5px;
    font-size: 12px; }
    .elementor-control-media__file__content__label {
      color: #a4afb7; }
    .elementor-control-media__file__content__info {
      display: -webkit-box;
      display: -ms-flexbox;
      display: flex;
      -webkit-box-align: center;
          -ms-flex-align: center;
              align-items: center;
      font-weight: 500; }
      .elementor-control-media__file__content__info__icon {
        margin-left: 5px; }
  .elementor-control-media__file__controls {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    border-right: 1px solid #d5dadf; }
    .elementor-control-media__file__controls__upload-button, .elementor-control-media__file__controls__remove {
      width: 27px;
      height: 27px;
      cursor: pointer;
      -webkit-box-align: center;
          -ms-flex-align: center;
              align-items: center; }
    .elementor-control-media__file__controls__upload-button {
      display: -webkit-box;
      display: -ms-flexbox;
      display: flex;
      -webkit-box-pack: center;
          -ms-flex-pack: center;
              justify-content: center; }
    .elementor-control-media__file__controls__remove {
      border-left: 1px solid #d5dadf; }

.elementor-control-media:not(.elementor-media-empty) .elementor-control-media__file__content__label {
  display: none; }

.elementor-control-media.elementor-media-empty .elementor-control-media__file__content__info {
  display: none; }

.elementor-control-media.elementor-media-empty .elementor-control-media__file__controls__remove {
  display: none; }

.elementor-control-media .elementor-control-dynamic-switcher {
  border: none;
  -webkit-border-radius: 0;
          border-radius: 0;
  background-color: rgba(109, 120, 130, 0.85);
  color: #fff; }
  .elementor-control-media .elementor-control-dynamic-switcher:hover {
    background-color: rgba(109, 120, 130, 0.95); }

.elementor-control-type-media.elementor-control-dynamic-value .elementor-control-input-wrapper {
  border: none; }

.elementor-control:not(.elementor-control-type-icons) .elementor-control-media__preview {
  background-color: #d5dadf; }

.elementor-control-type-number.elementor-control-dynamic input {
  -webkit-border-radius: 0 3px 3px 0;
          border-radius: 0 3px 3px 0;
  border-left: none; }

.elementor-control-type-number.elementor-control-dynamic .elementor-control-dynamic-switcher {
  -webkit-border-radius: 3px 0 0 3px;
          border-radius: 3px 0 0 3px; }

.elementor-control-type-order .elementor-control-oreder-wrapper {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex; }

.elementor-control-type-order input {
  display: none; }
  .elementor-control-type-order input:checked + .elementor-control-order-label {
    -webkit-transform: scale(1, -1);
        -ms-transform: scale(1, -1);
            transform: scale(1, -1); }

.elementor-control-type-order select {
  -webkit-border-radius: 3px 0 0 3px;
          border-radius: 3px 0 0 3px; }
  .elementor-control-type-order select:not(:focus) ~ .elementor-control-order-label {
    border-color: #d5dadf; }
  .elementor-control-type-order select:focus ~ .elementor-control-order-label {
    border-color: #a4afb7; }

.elementor-control-type-order .elementor-control-order-label {
  position: relative;
  padding: 0;
  width: 40px;
  border: 1px solid;
  font-size: 10px;
  -webkit-border-radius: 0 3px 3px 0;
          border-radius: 0 3px 3px 0;
  margin-left: -3px;
  background-color: #fff;
  cursor: pointer; }
  .elementor-control-type-order .elementor-control-order-label i {
    position: absolute;
    top: 50%;
    left: 50%;
    -webkit-transform: translate(-50%, -50%);
        -ms-transform: translate(-50%, -50%);
            transform: translate(-50%, -50%); }

.elementor-control-type-popover_toggle input {
  display: none; }

.elementor-control-type-popover_toggle label {
  cursor: pointer; }

.elementor-control-type-popover_toggle .elementor-control-input-wrapper {
  direction: ltr; }

.elementor-control-type-popover_toggle .elementor-control-popover-toggle-toggle:checked + .elementor-control-popover-toggle-toggle-label {
  color: #71d7f7; }

.elementor-control-type-popover_toggle .elementor-control-popover-toggle-toggle:not(:checked) ~ .elementor-control-popover-toggle-reset-label {
  display: none; }

.elementor-control-type-popover_toggle .elementor-control-popover-toggle-reset-label {
  color: #c2cbd2;
  margin-left: 5px; }

.elementor-control-type-popover_toggle .elementor-control-popover-toggle-toggle-label {
  height: 27px;
  display: -webkit-inline-box;
  display: -ms-inline-flexbox;
  display: inline-flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  -webkit-box-pack: center;
      -ms-flex-pack: center;
          justify-content: center;
  -webkit-border-radius: 3px;
          border-radius: 3px;
  border: 1px solid #d5dadf; }

.elementor-controls-popover.e-controls-popover--typography {
  padding-top: 0; }

.e-control-global .elementor-control-popover-toggle-toggle-label {
  -webkit-border-radius: 3px 0 0 3px;
          border-radius: 3px 0 0 3px;
  -ms-flex-negative: 0;
      flex-shrink: 0; }

.elementor-control-type-repeater .elementor-control:not(.elementor-control-type-tab) {
  padding-right: 10px;
  padding-left: 10px;
  padding-bottom: 10px; }

.elementor-control-type-repeater.elementor-repeater-has-minimum-rows .elementor-repeater-tool-remove {
  display: none; }

.elementor-control-type-repeater .elementor-repeater-fields {
  margin: 10px 0; }

.elementor-control-type-repeater .elementor-repeater-row-controls {
  border: 1px solid #d5dadf;
  border-top-width: 0;
  padding-top: 15px; }
  .elementor-control-type-repeater .elementor-repeater-row-controls:not(.editable) {
    display: none; }

.elementor-control-type-repeater .elementor-repeater-row-tools {
  display: table;
  table-layout: fixed;
  width: 100%;
  color: #556068;
  background-color: #d5dadf;
  height: 40px;
  border-spacing: 1px;
  -webkit-transition: all .5s;
  -o-transition: all .5s;
  transition: all .5s; }
  .elementor-control-type-repeater .elementor-repeater-row-tools:hover {
    background-color: #a4afb7; }
  .elementor-control-type-repeater .elementor-repeater-row-tools > div {
    display: table-cell;
    text-align: center;
    vertical-align: middle;
    cursor: pointer; }
    .elementor-control-type-repeater .elementor-repeater-row-tools > div:not(.elementor-repeater-row-handle-sortable) {
      background-color: #fff; }
    .elementor-control-type-repeater .elementor-repeater-row-tools > div:hover {
      opacity: .95; }
  .elementor-control-type-repeater .elementor-repeater-row-tools .elementor-repeater-row-item-title {
    text-align: right;
    padding: 0 10px;
    font-size: 12px;
    white-space: nowrap;
    -o-text-overflow: ellipsis;
       text-overflow: ellipsis;
    overflow: hidden; }
    .elementor-control-type-repeater .elementor-repeater-row-tools .elementor-repeater-row-item-title .eicon,
    .elementor-control-type-repeater .elementor-repeater-row-tools .elementor-repeater-row-item-title i,
    .elementor-control-type-repeater .elementor-repeater-row-tools .elementor-repeater-row-item-title svg {
      margin-left: 5px; }
    .elementor-control-type-repeater .elementor-repeater-row-tools .elementor-repeater-row-item-title img[src$="svg"] {
      width: 1em; }
  .elementor-control-type-repeater .elementor-repeater-row-tools .elementor-repeater-row-tool {
    width: 40px; }
  .elementor-control-type-repeater .elementor-repeater-row-tools .elementor-repeater-row-handle-sortable {
    cursor: move;
    width: 10px;
    color: #fff; }

.elementor-control-type-repeater .elementor-button-wrapper {
  text-align: center;
  padding-top: 5px; }

.elementor-control-type-section {
  margin-top: 10px;
  padding: 0; }
  .elementor-control-type-section.elementor-open {
    padding-bottom: 15px; }
  .elementor-control-type-section + .elementor-control:not(.elementor-control-type-section):before {
    display: none; }

.elementor-shadow-box .elementor-shadow-slider {
  margin-top: 10px; }

.elementor-shadow-box .elementor-color-picker-wrapper .elementor-control-title {
  -webkit-box-flex: 1;
      -ms-flex-positive: 1;
          flex-grow: 1; }

.elementor-control-type-slider.elementor-control-dynamic input {
  -webkit-border-radius: 0 3px 3px 0;
          border-radius: 0 3px 3px 0; }

.elementor-control-type-slider .elementor-control-unit-2 {
  width: 21%; }

.elementor-control-type-slider.elementor-control-type-slider--multiple .elementor-control-input-wrapper {
  display: block; }

.elementor-control-type-slider--multiple {
  padding-bottom: 40px; }
  .elementor-control-type-slider--multiple .elementor-slider {
    margin-top: 12px;
    width: 98%; }

.elementor-control-type-slider--handles-range .elementor-slider .noUi-handle {
  -webkit-border-radius: 0;
          border-radius: 0;
  width: 10px;
  -webkit-transform: translateY(calc(50% - 14px)) translateX(-4px);
      -ms-transform: translateY(calc(50% - 14px)) translateX(-4px);
          transform: translateY(calc(50% - 14px)) translateX(-4px); }
  .elementor-control-type-slider--handles-range .elementor-slider .noUi-handle:after {
    content: '';
    position: absolute;
    top: 2px;
    height: 12px;
    width: 11px;
    -webkit-transform: rotate(45deg);
        -ms-transform: rotate(45deg);
            transform: rotate(45deg);
    background-color: #fff;
    -webkit-border-radius: 3px;
            border-radius: 3px; }
  .elementor-control-type-slider--handles-range .elementor-slider .noUi-handle-lower:after {
    left: 5px;
    -webkit-box-shadow: 2px -2px 3px 0px rgba(0, 0, 0, 0.1);
            box-shadow: 2px -2px 3px 0px rgba(0, 0, 0, 0.1); }
  .elementor-control-type-slider--handles-range .elementor-slider .noUi-handle-upper:after {
    right: 5px;
    -webkit-box-shadow: -2px 2px 3px 0px rgba(0, 0, 0, 0.1);
            box-shadow: -2px 2px 3px 0px rgba(0, 0, 0, 0.1); }

.elementor-control-type-slider .elementor-control-dynamic-switcher {
  border-right-width: 0;
  -webkit-border-radius: 3px 0 0 3px;
          border-radius: 3px 0 0 3px; }

.elementor-control-type-slider .elementor-control-input-wrapper {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center; }

.elementor-control-type-slider .elementor-dynamic-cover {
  margin-top: 10px; }

.elementor-slider {
  -webkit-box-flex: 1;
      -ms-flex-positive: 1;
          flex-grow: 1;
  height: 4px;
  background-color: #d5dadf;
  -webkit-border-radius: 5px;
          border-radius: 5px;
  position: relative;
  cursor: pointer; }
  .elementor-slider-input {
    width: 21%;
    min-width: 54px;
    margin-right: 12px; }
  .elementor-slider__extra {
    position: relative; }
  .elementor-slider__labels {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-pack: justify;
        -ms-flex-pack: justify;
            justify-content: space-between; }
  .elementor-slider__label {
    font-size: 9px;
    color: #c2cbd2; }
  .elementor-slider__scales {
    position: absolute;
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-pack: space-evenly;
        -ms-flex-pack: space-evenly;
            justify-content: space-evenly;
    width: 100%;
    margin-top: 4px; }
  .elementor-slider__scale {
    width: 1px;
    height: 21px;
    background-color: #a4afb7; }
  .elementor-slider .noUi-handle {
    height: 16px;
    width: 16px;
    background-color: #fff;
    left: 0;
    -webkit-transform: translateY(calc(50% - 14px)) translateX(-8px);
        -ms-transform: translateY(calc(50% - 14px)) translateX(-8px);
            transform: translateY(calc(50% - 14px)) translateX(-8px);
    position: absolute;
    -webkit-box-shadow: 0 1px 5px rgba(0, 0, 0, 0.3);
            box-shadow: 0 1px 5px rgba(0, 0, 0, 0.3);
    -webkit-border-radius: 50%;
            border-radius: 50%; }
  .elementor-slider .noUi-connects {
    position: absolute;
    width: 100%;
    height: 4px; }
  .elementor-slider .noUi-connect {
    position: absolute;
    z-index: 0;
    top: 0;
    left: 0;
    height: 100%;
    width: 100%;
    will-change: transform;
    -webkit-transform-origin: 0 0;
        -ms-transform-origin: 0 0;
            transform-origin: 0 0;
    background-color: #a4afb7; }
  .elementor-slider .noUi-tooltip {
    position: absolute;
    top: calc(100% + 5px);
    left: calc(50% - 4px);
    -webkit-transform: translateX(-50%);
        -ms-transform: translateX(-50%);
            transform: translateX(-50%);
    font-size: 10px; }

.elementor-control-type-structure .elementor-control-field {
  display: initial; }

.elementor-control-type-structure .elementor-control-structure-preset {
  padding: 3px;
  -webkit-border-radius: 3px;
          border-radius: 3px;
  display: inline-block;
  cursor: pointer;
  height: 50px; }
  .elementor-control-type-structure .elementor-control-structure-preset svg {
    height: 100%; }
  .elementor-control-type-structure .elementor-control-structure-preset path {
    fill: #e6e9ec; }

.elementor-control-type-structure .elementor-control-structure-reset {
  padding: 15px 20px 0;
  font-size: 11px;
  cursor: pointer;
  color: #a4afb7;
  border-top: 1px solid #e6e9ec;
  margin: 0 -20px; }

.elementor-control-type-structure .elementor-control-structure-title {
  margin: 10px -20px 0; }
  .elementor-control-type-structure .elementor-control-structure-title:before {
    height: 10px;
    -webkit-box-shadow: inset 0 2px 4px rgba(127, 127, 127, 0.1);
            box-shadow: inset 0 2px 4px rgba(127, 127, 127, 0.1); }

.elementor-control-type-structure .elementor-control-structure-presets {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -ms-flex-wrap: wrap;
      flex-wrap: wrap;
  -webkit-box-pack: justify;
      -ms-flex-pack: justify;
          justify-content: space-between; }
  .elementor-control-type-structure .elementor-control-structure-presets input {
    display: none; }
    .elementor-control-type-structure .elementor-control-structure-presets input:checked + .elementor-control-structure-preset path {
      fill: #a4afb7; }

.elementor-control-type-structure .elementor-control-structure-preset-wrapper {
  margin-bottom: 15px; }

.elementor-control-type-structure .elementor-control-structure-preset-title {
  text-align: center;
  padding-top: 5px;
  font-style: italic;
  font-size: 11px;
  color: #a4afb7; }

.elementor-control-type-switcher .elementor-control-input-wrapper {
  text-align: left; }

.elementor-control-type-switcher .elementor-switch {
  position: relative;
  display: inline-block;
  vertical-align: top;
  height: 20px;
  background-color: white;
  -webkit-border-radius: 18px;
          border-radius: 18px;
  cursor: pointer; }

.elementor-control-type-switcher .elementor-switch-input {
  display: none; }

.elementor-control-type-switcher .elementor-switch-label {
  position: relative;
  display: block;
  height: inherit;
  font-size: 7px;
  text-transform: uppercase;
  background: #eceeef;
  -webkit-border-radius: inherit;
          border-radius: inherit;
  -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.12), inset 0 0 2px rgba(0, 0, 0, 0.15);
          box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.12), inset 0 0 2px rgba(0, 0, 0, 0.15);
  -webkit-transition: 0.15s ease-out;
  -o-transition: 0.15s ease-out;
  transition: 0.15s ease-out;
  -webkit-transition-property: opacity, background;
  -o-transition-property: opacity, background;
  transition-property: opacity, background; }

.elementor-control-type-switcher .elementor-switch-label:before, .elementor-control-type-switcher .elementor-switch-label:after {
  position: absolute;
  top: 0;
  width: 50%;
  text-align: center;
  line-height: 20px;
  -webkit-transition: inherit;
  -o-transition: inherit;
  transition: inherit; }

.elementor-control-type-switcher .elementor-switch-label:before {
  content: attr(data-off);
  right: 3px;
  color: #a4afb7;
  text-shadow: 0 1px rgba(255, 255, 255, 0.5); }

.elementor-control-type-switcher .elementor-switch-label:after {
  content: attr(data-on);
  left: 3px;
  color: white;
  text-shadow: 0 1px rgba(0, 0, 0, 0.2);
  opacity: 0; }

.elementor-control-type-switcher .elementor-switch-input:checked ~ .elementor-switch-label {
  background: #71d7f7;
  -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.15), inset 0 0 3px rgba(0, 0, 0, 0.2);
          box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.15), inset 0 0 3px rgba(0, 0, 0, 0.2); }
  .elementor-control-type-switcher .elementor-switch-input:checked ~ .elementor-switch-label:before {
    opacity: 0; }
  .elementor-control-type-switcher .elementor-switch-input:checked ~ .elementor-switch-label:after {
    opacity: 1; }

.elementor-control-type-switcher .elementor-switch-handle {
  position: absolute;
  top: 1px;
  left: 1px;
  width: 18px;
  height: 18px;
  background: white;
  -webkit-border-radius: 10px;
          border-radius: 10px;
  -webkit-transition: left 0.15s ease-out;
  -o-transition: left 0.15s ease-out;
  transition: left 0.15s ease-out; }

.elementor-control-type-switcher .elementor-switch-input:checked ~ .elementor-switch-handle {
  left: initial;
  right: 1px;
  -webkit-box-shadow: -1px 1px 5px rgba(0, 0, 0, 0.2);
          box-shadow: -1px 1px 5px rgba(0, 0, 0, 0.2); }

.elementor-control-type-tabs {
  font-size: 0.8em;
  text-transform: uppercase;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex; }

.elementor-control-type-tab {
  text-align: center;
  width: 100%;
  padding: 0;
  line-height: 25px;
  border-top: 1px solid #d5dadf;
  border-bottom: 1px solid #d5dadf;
  border-left: 1px solid #d5dadf;
  cursor: pointer; }
  .elementor-control-type-tab:first-child {
    border-right: 1px solid #d5dadf;
    -webkit-border-top-right-radius: 3px;
            border-top-right-radius: 3px;
    -webkit-border-bottom-right-radius: 3px;
            border-bottom-right-radius: 3px; }
  .elementor-control-type-tab:last-child {
    -webkit-border-top-left-radius: 3px;
            border-top-left-radius: 3px;
    -webkit-border-bottom-left-radius: 3px;
            border-bottom-left-radius: 3px; }
  .elementor-control-type-tab.elementor-tab-active {
    background-color: #a4afb7;
    border-color: #a4afb7;
    color: #ffffff; }

.elementor-tab-close {
  display: none !important; }

.elementor-control-type-textarea.elementor-control-dynamic-value .elementor-control-dynamic-switcher,
.elementor-control-type-code.elementor-control-dynamic-value .elementor-control-dynamic-switcher {
  -webkit-border-radius: 3px 0 0 3px;
          border-radius: 3px 0 0 3px;
  border-right-width: 0; }

.elementor-control-type-textarea .elementor-control-dynamic-switcher,
.elementor-control-type-code .elementor-control-dynamic-switcher {
  -webkit-border-radius: 0 3px;
          border-radius: 0 3px; }

.elementor-control-type-textarea:not(.elementor-control-dynamic-value) .elementor-control-dynamic-switcher,
.elementor-control-type-code:not(.elementor-control-dynamic-value) .elementor-control-dynamic-switcher {
  position: absolute;
  top: 0;
  z-index: 1;
  right: 0; }

.elementor-control-type-textarea .elementor-control-input-wrapper,
.elementor-control-type-code .elementor-control-input-wrapper {
  position: relative; }

.elementor-control-type-textarea textarea,
.elementor-control-type-code textarea {
  display: block;
  font-family: inherit; }
  .elementor-control-type-textarea textarea:focus + .elementor-control-dynamic-switcher,
  .elementor-control-type-code textarea:focus + .elementor-control-dynamic-switcher {
    display: none; }

.elementor-control-type-textarea pre:focus-within + .elementor-control-dynamic-switcher,
.elementor-control-type-code pre:focus-within + .elementor-control-dynamic-switcher {
  display: none; }

.elementor-control-type-url.elementor-control-dynamic .elementor-input {
  -webkit-border-radius: 3px 0 0 3px;
          border-radius: 3px 0 0 3px; }

.elementor-control-type-url .elementor-control-field {
  position: relative; }

.elementor-control-type-url:not(.elementor-control-dynamic) .elementor-control-url-more, .elementor-control-type-url.elementor-control-dynamic-value .elementor-control-url-more {
  -webkit-border-radius: 0 3px 3px 0;
          border-radius: 0 3px 3px 0; }

.elementor-control-type-url .elementor-control-input-wrapper {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: horizontal;
  -webkit-box-direction: reverse;
      -ms-flex-direction: row-reverse;
          flex-direction: row-reverse; }

.elementor-control-type-url .elementor-control-url-more {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  -webkit-box-pack: center;
      -ms-flex-pack: center;
          justify-content: center;
  -ms-flex-negative: 0;
      flex-shrink: 0;
  border: 1px solid #d5dadf;
  border-left: none;
  cursor: pointer; }
  .elementor-control-type-url .elementor-control-url-more i {
    font-size: 12px; }
  .elementor-control-type-url .elementor-control-url-more-options {
    display: none;
    padding-top: 10px; }
    .elementor-control-type-url .elementor-control-url-more-options .elementor-control-field-description {
      margin-top: 10px; }

.elementor-control-type-url .elementor-control-url-option {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center; }
  .elementor-control-type-url .elementor-control-url-option:not(:last-child) {
    padding-bottom: 10px; }
  .elementor-control-type-url .elementor-control-url-option input,
  .elementor-control-type-url .elementor-control-url-option label {
    cursor: pointer; }
  .elementor-control-type-url .elementor-control-url-option-input {
    margin: 0;
    padding: 0;
    -webkit-border-radius: 2px;
            border-radius: 2px;
    margin-left: 5px;
    -webkit-appearance: none;
    -moz-appearance: none;
    outline: none;
    content: none;
    height: 15px;
    width: 15px;
    border: 1px solid #d5dadf;
    display: -webkit-inline-box;
    display: -ms-inline-flexbox;
    display: inline-flex;
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center;
    -webkit-box-pack: center;
        -ms-flex-pack: center;
            justify-content: center; }
    .elementor-control-type-url .elementor-control-url-option-input:checked {
      background: #71d7f7;
      border: none; }
      .elementor-control-type-url .elementor-control-url-option-input:checked:before {
        display: block;
        content: "";
        width: 4px;
        height: 7px;
        border: solid white;
        border-width: 0 2px 2px 0;
        -webkit-transform: rotate(45deg);
            -ms-transform: rotate(45deg);
                transform: rotate(45deg); }
  .elementor-control-type-url .elementor-control-url-option label {
    font-size: 12px; }

.elementor-control-type-url .elementor-control-url-external-hide .elementor-control-url-more {
  display: none; }

.elementor-control-type-url .elementor-control-url-external-show .elementor-input,
.elementor-control-type-url .elementor-control-url-external-show .elementor-dynamic-cover {
  -webkit-border-radius: 3px 0 0 3px;
          border-radius: 3px 0 0 3px; }

.elementor-control-type-url .elementor-control-url-autocomplete-spinner {
  display: none;
  position: absolute;
  top: 5px;
  right: 0px;
  width: 10px;
  height: 10px;
  font-size: 10px;
  color: #D4D4D4; }

.elementor-control-type-url .elementor-control-url__custom-attributes {
  margin-top: 5px; }
  .elementor-control-type-url .elementor-control-url__custom-attributes label {
    font-size: 12px; }
  .elementor-control-type-url .elementor-control-url__custom-attributes input {
    width: 100%;
    margin-top: 10px; }

.elementor-control-type-url .elementor-input {
  direction: ltr; }
  .elementor-control-type-url .elementor-input:not(:focus) + .elementor-control-url-more {
    border-color: #d5dadf; }
  .elementor-control-type-url .elementor-input:focus ~ div {
    border-color: #a4afb7; }

.elementor-control-type-url .elementor-control-dynamic-switcher {
  border-left: none;
  -webkit-border-radius: 0 3px 3px 0;
          border-radius: 0 3px 3px 0; }

.elementor-autocomplete-menu {
  position: absolute;
  background: #fff;
  color: #495157;
  border: 1px solid #a4afb7;
  margin: 0;
  list-style: none;
  padding: 4px 0;
  height: auto;
  width: 100%;
  min-width: 260px;
  max-width: 300px;
  max-height: 200px;
  overflow-y: auto;
  -webkit-border-radius: 3px;
          border-radius: 3px;
  -webkit-transition: all .3s ease-in-out;
  -o-transition: all .3s ease-in-out;
  transition: all .3s ease-in-out;
  cursor: default;
  z-index: 1; }
  .elementor-autocomplete-menu .ui-menu-item {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-pack: justify;
        -ms-flex-pack: justify;
            justify-content: space-between;
    -ms-flex-item-align: baseline;
        align-self: baseline;
    padding: 5px 8px;
    font-size: 12px;
    width: 100%;
    line-height: 1.2;
    cursor: pointer; }
    .elementor-autocomplete-menu .ui-menu-item.ui-state-hover, .elementor-autocomplete-menu .ui-menu-item.ui-state-active, .elementor-autocomplete-menu .ui-menu-item.ui-state-focus {
      background: #e6e9ec; }
  .elementor-autocomplete-menu .elementor-autocomplete-item-info {
    font-size: 10px;
    padding-top: 2px; }

.elementor-control-type-wp_widget .widget-inside {
  display: block; }

.elementor-control-type-wp_widget .quicktags-toolbar input {
  width: auto; }

.elementor-control-type-wysiwyg * {
  -webkit-box-sizing: content-box;
          box-sizing: content-box; }

.elementor-control-type-wysiwyg .wp-editor-container {
  border: 1px solid #e6e9ec; }

.elementor-control-type-wysiwyg .wp-editor-tabs {
  border: 1px solid #d5dadf;
  border-bottom: none;
  -webkit-border-radius: 3px 3px 0 0;
          border-radius: 3px 3px 0 0; }

.elementor-control-type-wysiwyg #insert-media-button {
  height: initial;
  line-height: 24px;
  font-size: 10px;
  color: #6d7882;
  border-color: #d5dadf;
  background-color: #e6e9ec;
  min-height: initial; }

.elementor-control-type-wysiwyg .ed_button {
  height: 22px;
  width: initial; }

.elementor-control-type-wysiwyg .wp-media-buttons-icon {
  height: 14px;
  margin: 0; }
  .elementor-control-type-wysiwyg .wp-media-buttons-icon:before {
    font-size: 14px; }

.elementor-control-type-wysiwyg .wp-switch-editor {
  position: static;
  border: none;
  margin: 0;
  color: #6d7882;
  font-size: 10px;
  padding: 3px 9px 4px; }

.elementor-control-type-wysiwyg .switch-html {
  border: solid #d5dadf;
  border-width: 0 1px; }

.elementor-control-type-wysiwyg .html-active .switch-tmce {
  background-color: transparent; }

.elementor-control-type-wysiwyg .html-active .switch-html {
  background-color: #e6e9ec; }

.elementor-control-type-wysiwyg .tmce-active .switch-tmce {
  background-color: #e6e9ec; }

.elementor-control-type-wysiwyg .tmce-active .switch-html {
  background-color: transparent; }

.elementor-control-type-wysiwyg .mce-toolbar-grp, .elementor-control-type-wysiwyg .quicktags-toolbar {
  background-color: #e6e9ec; }

.elementor-control-type-wysiwyg .mce-toolbar-grp > div {
  padding: 0 3px; }

.elementor-control-type-wysiwyg .elementor-wp-editor {
  -webkit-box-sizing: border-box;
          box-sizing: border-box; }

.elementor-control-type-wysiwyg .mce-ico {
  color: #6d7882;
  font-size: 16px; }

.elementor-control-type-wysiwyg .mce-btn {
  margin-right: 0;
  margin-left: 0; }
  .elementor-control-type-wysiwyg .mce-btn:hover, .elementor-control-type-wysiwyg .mce-btn:active, .elementor-control-type-wysiwyg .mce-btn.mce-active {
    border-color: #d5dadf; }

.elementor-control-type-wysiwyg .mce-path {
  padding: 5px 10px; }

.elementor-control-type-wysiwyg .mce-path-item {
  font-size: 12px;
  color: #6d7882; }

.elementor-control-type-wysiwyg .elementor-control-dynamic-switcher {
  border: none; }

.elementor-control-type-text .elementor-control-dynamic-switcher {
  border-right-width: 0;
  -webkit-border-radius: 3px 0 0 3px;
          border-radius: 3px 0 0 3px; }

.elementor-control-type-text.elementor-control-dynamic input {
  -webkit-border-radius: 0 3px 3px 0;
          border-radius: 0 3px 3px 0; }

#elementor-mode-switcher {
  position: absolute;
  right: 100%;
  top: 50%;
  width: 15px;
  height: 50px;
  -webkit-transform: translateY(-50%);
      -ms-transform: translateY(-50%);
          transform: translateY(-50%);
  background-color: #e6e9ec;
  font-size: 15px;
  -webkit-box-shadow: -3px 1px 5px rgba(0, 0, 0, 0.1);
          box-shadow: -3px 1px 5px rgba(0, 0, 0, 0.1);
  cursor: pointer; }
  #elementor-mode-switcher:hover {
    background-color: #93003c;
    color: #FFFFFF; }

#elementor-mode-switcher-inner, #elementor-mode-switcher-preview {
  width: 100%;
  height: 100%;
  position: absolute;
  top: 0;
  left: 0; }

#elementor-mode-switcher-preview {
  cursor: pointer; }
  #elementor-mode-switcher-preview .eicon {
    position: absolute;
    top: 50%;
    left: 50%;
    -webkit-transform: translate(-50%, -50%);
        -ms-transform: translate(-50%, -50%);
            transform: translate(-50%, -50%); }

#elementor-mode-switcher-preview-input {
  display: none; }

:root {
  --e-is-device-mode: 0; }

.e-is-device-mode {
  --e-is-device-mode: 1; }

#elementor-responsive-bar {
  position: -webkit-sticky;
  position: sticky;
  height: calc(40px * var(--e-is-device-mode));
  -ms-flex-item-align: stretch;
      align-self: stretch;
  -ms-flex-negative: 0;
      flex-shrink: 0;
  -webkit-transition: height .2s ease-in-out, opacity .1s;
  -o-transition: height .2s ease-in-out, opacity .1s;
  transition: height .2s ease-in-out, opacity .1s;
  left: 0;
  top: 0;
  z-index: 100;
  opacity: var(--e-is-device-mode);
  -webkit-box-shadow: 0 0 10px 2px rgba(0, 0, 0, 0.33), 0 0 2px 1px rgba(0, 0, 0, 0.25), 0 0 6px -3px rgba(255, 255, 255, 0.5);
          box-shadow: 0 0 10px 2px rgba(0, 0, 0, 0.33), 0 0 2px 1px rgba(0, 0, 0, 0.25), 0 0 6px -3px rgba(255, 255, 255, 0.5); }
  #elementor-responsive-bar:before {
    content: "";
    position: absolute;
    left: 0;
    top: 0;
    width: 100%;
    height: 100%;
    z-index: -1;
    -webkit-transform: scaleX(var(--e-preview-scale, 1));
        -ms-transform: scaleX(var(--e-preview-scale, 1));
            transform: scaleX(var(--e-preview-scale, 1)); }

.e-responsive-bar-switcher__option {
  cursor: pointer;
  text-align: center;
  width: 22px;
  height: 22px;
  margin: 0 4px;
  line-height: 22px;
  -webkit-border-radius: 3px;
          border-radius: 3px;
  font-size: 16px;
  -webkit-transition: background-color .3s ease-out;
  -o-transition: background-color .3s ease-out;
  transition: background-color .3s ease-out; }
  .e-responsive-bar-switcher__option:hover, .e-responsive-bar-switcher__option[aria-selected="true"] {
    color: #c2cbd2;
    background-color: rgba(255, 255, 255, 0.1); }
  .e-responsive-bar-switcher__option input {
    display: none; }
    .e-responsive-bar-switcher__option input:checked + i {
      color: #71d7f7; }
  .e-responsive-bar-switcher__option:not(:last-child) {
    -webkit-margin-end: 6px;
            margin-inline-end: 6px; }

.e-responsive-bar__button {
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
  background: none;
  border: 0 none;
  cursor: pointer;
  color: inherit; }
  .e-responsive-bar__button:focus:not(:focus-visible) {
    outline: none; }
  .e-responsive-bar__button:hover {
    color: #c2cbd2;
    background-color: rgba(255, 255, 255, 0.1); }

.e-responsive-bar--pipe {
  position: relative; }
  .e-responsive-bar--pipe::before {
    content: '';
    display: block;
    height: 20px;
    width: 1px;
    background-color: #6d7882;
    position: absolute;
    left: -5px;
    top: calc(50% - 10px); }

.e-responsive-bar__input-size {
  background-color: transparent;
  color: #a4afb7;
  border: 1px solid #6d7882 !important;
  padding: 0 3px;
  width: 60px;
  font-size: 12px;
  line-height: 16px;
  height: 18px;
  margin: auto 8px auto 4px; }
  .e-responsive-bar__input-size-separator {
    color: #6d7882; }
  .e-responsive-bar__input-size[disabled] {
    background-color: transparent;
    color: #6d7882;
    cursor: default; }

#e-responsive-bar {
  width: 100%;
  margin-top: calc(-40px + (40px * var(--e-is-device-mode)));
  z-index: 1;
  -webkit-transition: margin-top .2s ease-in-out;
  -o-transition: margin-top .2s ease-in-out;
  transition: margin-top .2s ease-in-out;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  -webkit-box-pack: justify;
      -ms-flex-pack: justify;
          justify-content: space-between;
  color: #a4afb7;
  background-color: #495157; }
  #e-responsive-bar__center, #e-responsive-bar__end, #e-responsive-bar-scale, #e-responsive-bar-switcher {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-pack: center;
        -ms-flex-pack: center;
            justify-content: center;
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center;
    font-size: 13px;
    background-color: #495157;
    padding: 2px 0; }
  @media (min-width: 1400px) {
    #e-responsive-bar__center {
      margin-right: 50%;
      -webkit-transform: translate(50%, 0);
          -ms-transform: translate(50%, 0);
              transform: translate(50%, 0); } }
  #e-responsive-bar__close-button, #e-responsive-bar__settings-button {
    width: 22px;
    height: 22px;
    -webkit-border-radius: 3px;
            border-radius: 3px;
    margin: 7px 5px;
    font-size: 16px; }
  #e-responsive-bar__size-inputs-wrapper {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center;
    -webkit-margin-end: 8px;
            margin-inline-end: 8px;
    color: #6d7882; }
  #e-responsive-bar-switcher {
    padding: 0 20px; }
  #e-responsive-bar-scale {
    padding: 0 20px; }
    #e-responsive-bar-scale__value-wrapper {
      margin: 0 14px;
      min-width: 32px;
      text-align: center; }
    #e-responsive-bar-scale__plus, #e-responsive-bar-scale__minus, #e-responsive-bar-scale__reset {
      cursor: pointer;
      width: 20px;
      height: 20px;
      display: -webkit-box;
      display: -ms-flexbox;
      display: flex;
      -webkit-box-align: center;
          -ms-flex-align: center;
              align-items: center;
      -webkit-box-pack: center;
          -ms-flex-pack: center;
              justify-content: center; }
    #e-responsive-bar-scale__minus:before {
      content: "";
      display: block;
      width: 13px;
      height: 2px;
      background: #a4afb7;
      -webkit-border-radius: 3px;
              border-radius: 3px; }
    #e-responsive-bar-scale__reset {
      margin: 0px 8px; }

.elementor-revision-item__wrapper {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  border: 1px solid #d5dadf;
  padding: 10px 15px;
  margin-bottom: 10px;
  font-size: 11px;
  -webkit-transition: all 0.3s;
  -o-transition: all 0.3s;
  transition: all 0.3s; }
  .elementor-revision-item__wrapper.current {
    font-weight: bold; }
  .elementor-revision-item__wrapper .elementor-revision-item__tools-current {
    color: #71d7f7; }

.elementor-revision-item:hover:not(.elementor-revision-current-preview) {
  background-color: rgba(230, 233, 236, 0.3); }

.elementor-revision-item-loading .elementor-revision-item__tools-current {
  display: none; }

.elementor-revision-item:not(.elementor-revision-item-loading) .elementor-revision-item__tools-spinner {
  display: none; }

.elementor-revision-item__gravatar {
  -webkit-border-radius: 50%;
          border-radius: 50%;
  overflow: hidden; }
  .elementor-revision-item__gravatar img {
    display: block; }

.elementor-revision-item__details {
  padding-right: 15px;
  -webkit-box-flex: 1;
      -ms-flex-positive: 1;
          flex-grow: 1;
  cursor: pointer; }

.elementor-revision-meta {
  padding-top: 5px;
  font-size: 10px;
  font-weight: bold; }

.elementor-revision-current-preview {
  background-color: #e6e9ec; }

#elementor-restore-autosave-dialog.dialog-widget {
  background-color: rgba(0, 0, 0, 0.3); }

#elementor-panel-revisions-loading {
  position: absolute;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
      -ms-transform: translate(-50%, -50%);
          transform: translate(-50%, -50%); }
  #elementor-panel-revisions-loading .eicon-loading {
    font-size: 50px;
    color: #a4afb7; }

.elementor-history-item {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  border: 1px solid #d5dadf;
  padding: 10px 15px;
  margin-bottom: 10px;
  font-size: 11px;
  line-height: 1.4;
  cursor: pointer;
  -webkit-transition: all 0.3s;
  -o-transition: all 0.3s;
  transition: all 0.3s; }
  .elementor-history-item:hover {
    background-color: rgba(230, 233, 236, 0.3); }
    .elementor-history-item:hover .elementor-history-item__icon .eicon:before {
      content: '\e924'; }
  .elementor-history-item-applied {
    color: #a4afb7; }
  .elementor-history-item-current {
    background: #e6e9ec;
    cursor: default; }
    .elementor-history-item-current .elementor-history-item__icon .eicon:before, .elementor-history-item-current:hover .elementor-history-item__icon .eicon:before {
      content: '\e90e'; }
  .elementor-history-item__details {
    width: 95%; }
  .elementor-history-item__title {
    font-weight: bold; }
  .elementor-history-item__subtitle, .elementor-history-item__action {
    font-weight: lighter; }
  .elementor-history-item__action {
    font-style: italic;
    text-decoration: underline; }
  .elementor-history-item .__icon {
    float: left; }

.elementor-history-revisions-message {
  font-size: 11px;
  text-align: center;
  padding-top: 5px; }

#elementor-panel-history {
  padding: 20px 20px 15px; }
  #elementor-panel-history.elementor-empty .elementor-history-revisions-message {
    padding-top: 20px; }
  #elementor-panel-history:not(.elementor-empty) {
    background-color: #fff;
    margin-top: 10px; }

#elementor-panel-history-no-items,
#elementor-panel-revisions-no-revisions {
  text-align: center; }
  #elementor-panel-history-no-items .elementor-nerd-box-icon,
  #elementor-panel-revisions-no-revisions .elementor-nerd-box-icon {
    margin-top: 20px; }

.elementor-panel #elementor-panel-header #elementor-panel-header-kit-close,
.elementor-panel #elementor-panel-header #elementor-panel-header-kit-back {
  display: none; }

.elementor-editor-kit .elementor-panel #elementor-panel-header {
  background-color: #4ab7f4; }
  .elementor-editor-kit .elementor-panel #elementor-panel-header #elementor-panel-header-kit-close,
  .elementor-editor-kit .elementor-panel #elementor-panel-header #elementor-panel-header-kit-back {
    display: table-cell; }
  body:not(.e-routes-has-history) #elementor-panel-header-kit-back {
    pointer-events: none;
    opacity: 0.4; }
    body:not(.e-routes-has-history) #elementor-panel-header-kit-back:hover .elementor-icon {
      cursor: inherit;
      color: inherit; }

.elementor-editor-kit .elementor-panel .elementor-panel-navigation .elementor-panel-navigation-tab.elementor-active {
  border-bottom-color: #4ab7f4; }

.elementor-editor-kit .elementor-panel #elementor-panel-page-settings .elementor-panel-navigation {
  display: none; }

.elementor-editor-kit .elementor-panel #elementor-panel-saver-button-publish.elementor-button.elementor-button-success:not(.elementor-disabled),
.elementor-editor-kit .elementor-panel #elementor-panel-saver-button-save-options.elementor-button.elementor-button-success:not(.elementor-disabled) {
  background-color: #4ab7f4; }

.elementor-editor-kit .elementor-panel #elementor-panel-page-menu {
  padding: 25px 15px 0; }

.elementor-editor-kit #elementor-panel-header-add-button,
.elementor-editor-kit #elementor-panel-header-menu-button,
.elementor-editor-kit #elementor-panel-footer-sub-menu-item-save-template,
.elementor-editor-kit #elementor-panel-footer-navigator {
  display: none; }

.elementor-control-type-global-style-repeater .elementor-repeater-fields {
  margin-bottom: 15px;
  position: relative; }

.elementor-control-type-global-style-repeater .elementor-repeater-row-controls {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center; }

.elementor-control-type-global-style-repeater .elementor-repeater-row-tool {
  cursor: pointer;
  color: #d5dadf;
  padding: 5px; }

.elementor-control-type-global-style-repeater .elementor-control {
  padding: 0; }
  .elementor-control-type-global-style-repeater .elementor-control-title {
    -webkit-box-flex: 1;
        -ms-flex-positive: 1;
            flex-grow: 1; }
    .elementor-control-type-global-style-repeater .elementor-control-title input {
      max-width: 135px; }
      .elementor-control-type-global-style-repeater .elementor-control-title input:not(:focus) {
        background: none;
        border: none; }
  .elementor-control-type-global-style-repeater .elementor-control-input-wrapper {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center;
    min-width: 81px; }
    .elementor-control-type-global-style-repeater .elementor-control-input-wrapper:hover .e-global-colors__color-value {
      display: none; }
    .elementor-control-type-global-style-repeater .elementor-control-input-wrapper:not(:hover) .elementor-repeater-tool-remove,
    .elementor-control-type-global-style-repeater .elementor-control-input-wrapper:not(:hover) .elementor-repeater-tool-remove--disabled {
      display: none; }

.elementor-control-type-global-style-repeater .elementor-control-content > .elementor-control-field > .elementor-control-input-wrapper {
  margin-top: 0; }

.elementor-control-type-global-style-repeater .elementor-controls-popover {
  -ms-flex-item-align: end;
      align-self: end;
  margin-top: 35px;
  top: 0;
  width: 100%; }
  .elementor-control-type-global-style-repeater .elementor-controls-popover:before {
    left: 5px; }
  .elementor-control-type-global-style-repeater .elementor-controls-popover .elementor-control {
    padding: 0 20px 15px; }
    .elementor-control-type-global-style-repeater .elementor-controls-popover .elementor-control-title {
      -webkit-box-flex: initial;
          -ms-flex-positive: initial;
              flex-grow: initial; }

.elementor-control-type-global-style-repeater .elementor-button-wrapper {
  text-align: center;
  border-top: 1px solid #e6e9ec;
  max-width: 260px;
  padding-top: 15px; }

.elementor-control-type-global-style-repeater .pickr,
.elementor-control-type-global-style-repeater .elementor-control-popover-toggle-toggle-label {
  margin-right: 5px; }

.elementor-control-system_colors, .elementor-control-system_typography {
  padding-bottom: 0; }

.e-global-colors__color-value {
  color: #d5dadf;
  font-size: 10px;
  padding: 0 5px;
  text-align: left;
  white-space: nowrap;
  -o-text-overflow: ellipsis;
     text-overflow: ellipsis;
  overflow: hidden; }

@-webkit-keyframes load {
  0% {
    opacity: .3; }
  50% {
    opacity: 1; }
  100% {
    opacity: .3; } }

@keyframes load {
  0% {
    opacity: .3; }
  50% {
    opacity: 1; }
  100% {
    opacity: .3; } }

@-webkit-keyframes fadeIn {
  from {
    opacity: 0; }
  to {
    opacity: 1; } }

@keyframes fadeIn {
  from {
    opacity: 0; }
  to {
    opacity: 1; } }

@-webkit-keyframes mover {
  0% {
    -webkit-transform: translateY(0);
            transform: translateY(0); }
  100% {
    -webkit-transform: translateY(-5px);
            transform: translateY(-5px); } }

@keyframes mover {
  0% {
    -webkit-transform: translateY(0);
            transform: translateY(0); }
  100% {
    -webkit-transform: translateY(-5px);
            transform: translateY(-5px); } }

@-webkit-keyframes slideDown {
  0% {
    -webkit-transform: translateY(-30px);
            transform: translateY(-30px); }
  100% {
    -webkit-transform: translateY(0);
            transform: translateY(0); } }

@keyframes slideDown {
  0% {
    -webkit-transform: translateY(-30px);
            transform: translateY(-30px); }
  100% {
    -webkit-transform: translateY(0);
            transform: translateY(0); } }

body {
  --e-preview-width: calc(100% - var(--e-editor-panel-width, 300px)); }
  body.elementor-navigator-docked {
    --e-preview-width: calc(100% - var(--e-editor-panel-width, 300px) - var(--e-editor-navigator-width, 0px)); }
  body.elementor-device-desktop #elementor-preview {
    overflow-y: hidden;
    -webkit-box-align: start;
        -ms-flex-align: start;
            align-items: flex-start; }
  body:not(.elementor-device-desktop) body {
    overflow-y: auto; }

#elementor-preview {
  overflow: auto;
  background-color: #333;
  height: 100%;
  border: 0;
  width: var(--e-preview-width);
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
      -ms-flex-direction: column;
          flex-direction: column;
  -webkit-box-pack: start;
      -ms-flex-pack: start;
          justify-content: flex-start;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  position: relative;
  direction: ltr; }
  #elementor-preview > div {
    direction: rtl; }

#elementor-preview-responsive-wrapper {
  -webkit-transform-origin: top center;
      -ms-transform-origin: top center;
          transform-origin: top center;
  padding: 20px;
  -webkit-transform: scale(var(--e-preview-scale, 1));
      -ms-transform: scale(var(--e-preview-scale, 1));
          transform: scale(var(--e-preview-scale, 1)); }
  .elementor-device-desktop #elementor-preview-responsive-wrapper {
    min-width: 1025px;
    width: 100%;
    height: 100%;
    padding: 0;
    position: relative; }
  body.e-is-device-mode:not(.elementor-device-desktop) #elementor-preview-responsive-wrapper {
    width: var(--e-editor-preview-width);
    height: var(--e-editor-preview-height);
    margin: 0 Max(calc((100vw - var(--e-editor-panel-width) - var(--e-editor-preview-width)) / 2), 20px);
    -webkit-box-sizing: content-box;
            box-sizing: content-box;
    position: relative;
    max-height: calc(100vh - 80px); }
    body.e-is-device-mode:not(.elementor-device-desktop) #elementor-preview-responsive-wrapper .ui-resizable-handle {
      display: -webkit-box !important;
      display: -ms-flexbox !important;
      display: flex !important; }
  #elementor-preview-responsive-wrapper:not(.ui-resizable-resizing) {
    -webkit-transition: .3s ease-in-out;
    -o-transition: .3s ease-in-out;
    transition: .3s ease-in-out; }
  #elementor-preview-responsive-wrapper .ui-resizable-handle {
    top: 0; }
    #elementor-preview-responsive-wrapper .ui-resizable-handle.ui-resizable-s {
      top: auto;
      bottom: 0; }
  #elementor-preview-responsive-wrapper .ui-resizable-n, #elementor-preview-responsive-wrapper .ui-resizable-s {
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center;
    -webkit-box-pack: center;
        -ms-flex-pack: center;
            justify-content: center;
    height: 20px; }
    #elementor-preview-responsive-wrapper .ui-resizable-n:before, #elementor-preview-responsive-wrapper .ui-resizable-s:before {
      content: '';
      display: block;
      background-color: rgba(255, 255, 255, 0.2);
      width: 50px;
      height: 4px;
      -webkit-border-radius: 3px;
              border-radius: 3px;
      -webkit-transition: all 0.2s ease-in-out;
      -o-transition: all 0.2s ease-in-out;
      transition: all 0.2s ease-in-out; }
    #elementor-preview-responsive-wrapper .ui-resizable-n:hover:before, #elementor-preview-responsive-wrapper .ui-resizable-s:hover:before {
      background-color: rgba(255, 255, 255, 0.6);
      width: 100px; }
  #elementor-preview-responsive-wrapper .ui-resizable-e, #elementor-preview-responsive-wrapper .ui-resizable-w {
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center;
    -webkit-box-pack: center;
        -ms-flex-pack: center;
            justify-content: center;
    width: 20px; }
    #elementor-preview-responsive-wrapper .ui-resizable-e:before, #elementor-preview-responsive-wrapper .ui-resizable-w:before {
      content: '';
      display: block;
      background-color: rgba(255, 255, 255, 0.2);
      width: 4px;
      height: 50px;
      -webkit-border-radius: 3px;
              border-radius: 3px;
      -webkit-transition: all 0.2s ease-in-out;
      -o-transition: all 0.2s ease-in-out;
      transition: all 0.2s ease-in-out; }
    #elementor-preview-responsive-wrapper .ui-resizable-e:hover:before, #elementor-preview-responsive-wrapper .ui-resizable-w:hover:before {
      background-color: rgba(255, 255, 255, 0.6);
      height: 100px; }
  #elementor-preview-responsive-wrapper.ui-resizable-resizing .ui-resizable-handle:before {
    background-color: rgba(255, 255, 255, 0.9); }
  #elementor-preview-responsive-wrapper .ui-resizable-s {
    bottom: 0; }
  #elementor-preview-responsive-wrapper .ui-resizable-e {
    right: 0; }
  #elementor-preview-responsive-wrapper .ui-resizable-w {
    left: 0; }

#elementor-preview-iframe {
  width: 100%;
  height: 100%;
  background-color: #fff;
  -webkit-box-shadow: 0 0 3px rgba(0, 0, 0, 0.3), 0 0 20px rgba(0, 0, 0, 0.15);
          box-shadow: 0 0 3px rgba(0, 0, 0, 0.3), 0 0 20px rgba(0, 0, 0, 0.15); }

#elementor-template-library-modal a.elementor-template-library-blank-footer-link {
  font-style: normal;
  text-decoration: underline;
  color: #39b54a; }
  #elementor-template-library-modal a.elementor-template-library-blank-footer-link:hover {
    color: #2d8e3a; }

#elementor-template-library-modal .dialog-buttons-wrapper {
  display: none; }

#elementor-template-library-modal .select2-container {
  z-index: 0; }

#elementor-template-library-header-menu {
  text-align: center;
  color: #6d7882;
  font-size: 13px; }

.elementor-template-library-menu-item {
  display: inline-block;
  padding: 17px 0;
  width: 115px;
  cursor: pointer; }
  .elementor-template-library-menu-item.elementor-active {
    background-image: -webkit-gradient(linear, left top, left bottom, from(#f1f3f5), to(#fff));
    background-image: -webkit-linear-gradient(top, #f1f3f5, #fff);
    background-image: -o-linear-gradient(top, #f1f3f5, #fff);
    background-image: linear-gradient(to bottom, #f1f3f5, #fff);
    border-bottom: 3px solid #93003c; }

#elementor-template-library-header-actions {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex; }
  #elementor-template-library-header-actions > div {
    padding-left: 16px; }

#elementor-template-library-header-preview-insert-wrapper {
  cursor: default;
  padding: 0 10px; }
  #elementor-template-library-header-preview-insert-wrapper .elementor-button {
    padding: 8px 14px;
    font-size: 11px; }
  #elementor-template-library-header-preview-insert-wrapper .elementor-template-library-template-insert {
    color: #fff;
    background-color: #39b54a; }
  #elementor-template-library-header-preview-insert-wrapper .elementor-go-pro {
    background-color: #93003c;
    color: #fff; }

#elementor-template-library-header-preview-back {
  padding: 16.5px 0 15px 16.5px;
  border-left: 1px solid #e6e9ec;
  cursor: pointer;
  -webkit-transition: color .5s;
  -o-transition: color .5s;
  transition: color .5s; }
  #elementor-template-library-header-preview-back:not(:hover) {
    color: #a4afb7; }
  #elementor-template-library-header-preview-back i {
    padding-left: 10px;
    font-size: 18px; }
    #elementor-template-library-header-preview-back i:before {
      content: ""; }

#elementor-template-library-templates {
  padding: 0 15px; }
  #elementor-template-library-templates[data-template-source="local"] #elementor-template-library-templates-container {
    -webkit-box-shadow: 1px 1px 20px 0 rgba(0, 0, 0, 0.03);
            box-shadow: 1px 1px 20px 0 rgba(0, 0, 0, 0.03);
    margin-top: 10px;
    margin-bottom: 45px; }
  #elementor-template-library-templates[data-template-source="local"] .elementor-template-library-order-input:checked + .elementor-template-library-order-label {
    color: #6d7882; }
  #elementor-template-library-templates[data-template-source="remote"] #elementor-template-library-templates-container {
    margin: 10px -15px 0; }
  #elementor-template-library-templates[data-template-source="remote"] .elementor-template-library-order-input:checked + .elementor-template-library-order-label {
    color: #495157; }
  #elementor-template-library-templates[data-template-source="empty"] #elementor-template-library-order-toolbar-local, #elementor-template-library-templates[data-template-source="empty"] #elementor-template-library-footer-banner {
    display: none; }
  #elementor-template-library-templates.elementor-templates-filter-active #elementor-template-library-footer-banner {
    display: none; }
  #elementor-template-library-templates .elementor-template-library-order-input {
    display: none; }
    #elementor-template-library-templates .elementor-template-library-order-input:checked + .elementor-template-library-order-label {
      padding-left: 8px; }
      #elementor-template-library-templates .elementor-template-library-order-input:checked + .elementor-template-library-order-label:after {
        font-family: eicons;
        content: '\e8ae';
        margin-right: 3px; }
    #elementor-template-library-templates .elementor-template-library-order-input:checked.elementor-template-library-order-reverse + .elementor-template-library-order-label:after {
      content: '\e8ad'; }

#elementor-template-library-templates-container {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -ms-flex-wrap: wrap;
      flex-wrap: wrap;
  -webkit-box-align: start;
      -ms-flex-align: start;
          align-items: flex-start; }
  #elementor-template-library-templates-container .elementor-template-library-template-local .elementor-template-library-template-insert {
    text-transform: none;
    font-size: 12px; }

#elementor-template-library-toolbar {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
      -ms-flex-pack: justify;
          justify-content: space-between;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center; }

.elementor-template-library-filter-toolbar {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center; }

#elementor-template-library-filter-toolbar-remote {
  font-size: 11px; }

#elementor-template-library-order {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  border-left: 1px solid #d5dadf; }

.elementor-template-library-order-label {
  text-transform: uppercase;
  padding-left: 22px;
  -webkit-user-select: none;
     -moz-user-select: none;
      -ms-user-select: none;
          user-select: none; }

label.elementor-template-library-order-label {
  cursor: pointer; }
  label.elementor-template-library-order-label:hover {
    color: #556068; }

#elementor-template-library-filter .select2 {
  text-align: right;
  width: calc(27px * 5) !important; }

#elementor-template-library-filter .select2-selection__rendered {
  text-transform: capitalize; }

#select2-elementor-template-library-filter-subtype-results .select2-results__option {
  text-transform: capitalize;
  text-align: right;
  padding-right: 5px; }

#elementor-template-library-my-favorites {
  -webkit-box-flex: 1;
      -ms-flex-positive: 1;
          flex-grow: 1;
  text-align: right;
  padding-right: 20px; }

#elementor-template-library-filter-my-favorites {
  display: none; }
  #elementor-template-library-filter-my-favorites:checked + #elementor-template-library-filter-my-favorites-label {
    color: #495157; }
    #elementor-template-library-filter-my-favorites:checked + #elementor-template-library-filter-my-favorites-label i:after {
      color: #93003c;
      content: '\e93f'; }

#elementor-template-library-filter-my-favorites-label {
  cursor: pointer;
  text-transform: uppercase; }
  #elementor-template-library-filter-my-favorites-label:hover {
    color: #556068; }
    #elementor-template-library-filter-my-favorites-label:hover i:after {
      color: #93003c; }
  #elementor-template-library-filter-my-favorites-label i {
    padding-left: 5px; }
    #elementor-template-library-filter-my-favorites-label i:after {
      color: #a4afb7;
      content: '\e923'; }

#elementor-template-library-filter-text-wrapper {
  width: 200px;
  position: relative; }
  #elementor-template-library-filter-text-wrapper i {
    position: absolute;
    top: 50%;
    left: 0;
    -webkit-transform: translateY(-50%);
        -ms-transform: translateY(-50%);
            transform: translateY(-50%); }

#elementor-template-library-filter-text {
  border: none;
  border-bottom: 1px solid #d5dadf;
  -webkit-border-radius: 0;
          border-radius: 0;
  font-size: 11px;
  padding: 8px 15px 8px 0;
  -webkit-transition: border 0.5s;
  -o-transition: border 0.5s;
  transition: border 0.5s; }
  #elementor-template-library-filter-text:focus {
    border-color: #c2cbd2; }
  #elementor-template-library-filter-text::-webkit-input-placeholder {
    font-weight: 300;
    text-transform: uppercase; }
  #elementor-template-library-filter-text::-moz-placeholder {
    font-weight: 300;
    text-transform: uppercase; }
  #elementor-template-library-filter-text::-ms-input-placeholder {
    font-weight: 300;
    text-transform: uppercase; }
  #elementor-template-library-filter-text::placeholder {
    font-weight: 300;
    text-transform: uppercase; }
  #elementor-template-library-filter-text:focus {
    border-color: #c2cbd2; }

.elementor-template-library-template-remote {
  margin: 15px;
  padding: 8px;
  background-color: #fff;
  -webkit-box-shadow: 0 1px 20px 0 rgba(0, 0, 0, 0.07);
          box-shadow: 0 1px 20px 0 rgba(0, 0, 0, 0.07);
  -webkit-border-radius: 3px;
          border-radius: 3px; }
  .elementor-template-library-template-remote:hover .elementor-template-library-template-name {
    display: none; }
  .elementor-template-library-template-remote:not(:hover) .elementor-template-library-template-preview {
    opacity: 0; }
  .elementor-template-library-template-remote:not(:hover) .elementor-template-library-favorite,
  .elementor-template-library-template-remote:not(:hover) .elementor-template-library-template-action {
    display: none; }
  .elementor-template-library-template-remote.elementor-template-library-pro-template .elementor-template-library-template-body:before {
    content: var(--elementor-template-library-subscription-plan-label);
    background-color: var(--elementor-template-library-subscription-plan-color);
    color: #d5dadf;
    position: absolute;
    text-transform: uppercase;
    top: 5px;
    left: 5px;
    padding: 2px 4px 0;
    font-size: 9px;
    -webkit-border-radius: 2px;
            border-radius: 2px; }
  .elementor-template-library-template-remote:not(.elementor-template-library-template-page):not(.elementor-template-library-template-lp) {
    position: relative;
    width: calc(33.333% - 30px);
    overflow: hidden; }
    .elementor-template-library-template-remote:not(.elementor-template-library-template-page):not(.elementor-template-library-template-lp) img {
      display: block;
      width: 100%; }
    .elementor-template-library-template-remote:not(.elementor-template-library-template-page):not(.elementor-template-library-template-lp) .elementor-template-library-template-footer {
      position: absolute;
      width: 100%;
      bottom: 0;
      right: 0;
      padding: 10px;
      background-color: #fff;
      -webkit-transition: -webkit-transform .5s;
      transition: -webkit-transform .5s;
      -o-transition: transform .5s;
      transition: transform .5s;
      transition: transform .5s, -webkit-transform .5s; }
    .elementor-template-library-template-remote:not(.elementor-template-library-template-page):not(.elementor-template-library-template-lp) .elementor-template-library-template-name {
      display: none; }
    .elementor-template-library-template-remote:not(.elementor-template-library-template-page):not(.elementor-template-library-template-lp):not(:hover) .elementor-template-library-template-footer {
      -webkit-transform: translateY(100%);
          -ms-transform: translateY(100%);
              transform: translateY(100%); }
  .elementor-template-library-template-remote .elementor-template-library-template-body {
    position: relative; }
  @media (max-width: 1025px) {
    .elementor-template-library-template-remote .elementor-template-library-template-body {
      height: 300px; } }
  .elementor-template-library-template-remote .elementor-template-library-template-screenshot {
    height: 100%;
    -webkit-background-size: cover;
            background-size: cover;
    background-position-x: 50%;
    -webkit-box-shadow: inset 0px -2px 15px -6px rgba(0, 0, 0, 0.07);
            box-shadow: inset 0px -2px 15px -6px rgba(0, 0, 0, 0.07); }
  .elementor-template-library-template-remote .elementor-template-library-template-preview {
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    background-color: rgba(0, 0, 0, 0.5);
    -webkit-transition: opacity .5s;
    -o-transition: opacity .5s;
    transition: opacity .5s;
    cursor: pointer; }
    .elementor-template-library-template-remote .elementor-template-library-template-preview i {
      font-size: 20px;
      color: #d5dadf;
      position: absolute;
      top: 50%;
      left: 50%;
      -webkit-transform: translate(-50%, -50%);
          -ms-transform: translate(-50%, -50%);
              transform: translate(-50%, -50%); }
  .elementor-template-library-template-remote .elementor-template-library-template-insert {
    color: #39b54a; }
  .elementor-template-library-template-remote .elementor-go-pro {
    color: #93003c; }
  .elementor-template-library-template-remote .elementor-template-library-template-footer {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-pack: justify;
        -ms-flex-pack: justify;
            justify-content: space-between;
    margin-top: 10px;
    font-size: 11px;
    line-height: 1; }
  .elementor-template-library-template-remote .elementor-template-library-template-name {
    text-align: right;
    color: #6d7882;
    -webkit-box-flex: 1;
        -ms-flex-positive: 1;
            flex-grow: 1;
    white-space: nowrap;
    -o-text-overflow: ellipsis;
       text-overflow: ellipsis;
    overflow: hidden;
    padding-left: 5px; }
  .elementor-template-library-template-remote .elementor-template-library-template-favorite-input {
    display: none; }
    .elementor-template-library-template-remote .elementor-template-library-template-favorite-input:checked + .elementor-template-library-template-favorite-label i:before {
      content: '\e93f';
      color: #93003c; }
  .elementor-template-library-template-remote .elementor-template-library-template-favorite-label {
    cursor: pointer; }
    .elementor-template-library-template-remote .elementor-template-library-template-favorite-label:hover i {
      color: #93003c; }

@media (max-width: 1439px) {
  .elementor-template-library-template-page,
  .elementor-template-library-template-lp {
    width: calc(25% - 30px); } }

@media (min-width: 1440px) {
  .elementor-template-library-template-page,
  .elementor-template-library-template-lp {
    width: calc(20% - 30px); } }

@media (max-width: 1025px) {
  .elementor-template-library-template-page,
  .elementor-template-library-template-lp {
    width: calc(33.333% - 30px); } }

.elementor-template-library-template-page .elementor-template-library-template-body,
.elementor-template-library-template-lp .elementor-template-library-template-body {
  height: 200px; }

#elementor-template-library-order-toolbar-local,
.elementor-template-library-template-local {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  padding: 0 25px;
  text-align: right; }

#elementor-template-library-order-toolbar-local {
  margin-top: 30px; }
  #elementor-template-library-order-toolbar-local .elementor-template-library-order-label {
    line-height: 1;
    font-size: 10px;
    font-weight: 500; }
    #elementor-template-library-order-toolbar-local .elementor-template-library-order-label:not(:hover) {
      color: #a4afb7; }

.elementor-template-library-template-local {
  height: 50px;
  width: 100%;
  margin-top: 1px;
  background-color: #fff;
  -webkit-transition: background-color .3s linear;
  -o-transition: background-color .3s linear;
  transition: background-color .3s linear; }
  .elementor-template-library-template-local:hover {
    background-color: #fafbfb; }
  .elementor-template-library-template-local:not(:hover) .elementor-template-library-template-insert {
    background: none;
    color: #a4afb7; }
  .elementor-template-library-template-local:first-child {
    -webkit-border-radius: 3px 3px 0 0;
            border-radius: 3px 3px 0 0; }
  .elementor-template-library-template-local:last-child {
    -webkit-border-radius: 0 0 3px 3px;
            border-radius: 0 0 3px 3px; }
  .elementor-template-library-template-local .elementor-template-library-template-name {
    font-weight: 500; }
  .elementor-template-library-template-local .elementor-template-library-template-name,
  .elementor-template-library-template-local .elementor-template-library-template-meta {
    padding-left: 20px; }
  .elementor-template-library-template-local .elementor-template-library-template-meta {
    color: #a4afb7; }
  .elementor-template-library-template-local .elementor-template-library-template-name,
  .elementor-template-library-template-local .elementor-template-library-template-meta,
  .elementor-template-library-template-local .elementor-template-library-template-preview,
  .elementor-template-library-template-local .elementor-template-library-template-action {
    white-space: nowrap;
    -o-text-overflow: ellipsis;
       text-overflow: ellipsis;
    overflow: hidden; }
  .elementor-template-library-template-local .elementor-template-library-template-controls {
    position: relative;
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center; }
    .elementor-template-library-template-local .elementor-template-library-template-controls,
    .elementor-template-library-template-local .elementor-template-library-template-controls a {
      color: #a4afb7; }
    .elementor-template-library-template-local .elementor-template-library-template-controls > div {
      cursor: pointer;
      -webkit-transition: color .5s;
      -o-transition: color .5s;
      transition: color .5s; }
  .elementor-template-library-template-local .elementor-template-library-template-insert i {
    margin-left: 3px; }
  .elementor-template-library-template-local .elementor-template-library-template-control-title {
    margin-right: 6px; }
  .elementor-template-library-template-local .elementor-template-library-template-more:hover,
  .elementor-template-library-template-local .elementor-template-library-template-more a:hover {
    color: #556068; }
  .elementor-template-library-template-local .elementor-template-library-template-more .elementor-template-library-template-delete:hover {
    color: #d72b3f; }
  .elementor-template-library-template-local .elementor-template-library-template-action {
    padding: 8px 18px;
    margin: 0 5%; }
  .elementor-template-library-template-local .elementor-template-library-template-more {
    display: none;
    position: absolute;
    background-color: #fff;
    padding: 3px 20px;
    -webkit-border-radius: 3px;
            border-radius: 3px;
    -webkit-box-shadow: 1px 3px 11px rgba(0, 0, 0, 0.3);
            box-shadow: 1px 3px 11px rgba(0, 0, 0, 0.3);
    top: 100%;
    left: 0;
    -webkit-transform: translateX(-65%) translateY(-7px);
        -ms-transform: translateX(-65%) translateY(-7px);
            transform: translateX(-65%) translateY(-7px);
    z-index: 1; }
    .elementor-template-library-template-local .elementor-template-library-template-more:before {
      content: '';
      position: absolute;
      border: solid transparent;
      border-width: 8px 4px;
      border-bottom-color: #fff;
      -webkit-transform: translateY(-100%);
          -ms-transform: translateY(-100%);
              transform: translateY(-100%); }
    .elementor-template-library-template-local .elementor-template-library-template-more > div {
      margin: 10px 0;
      font-size: 11px; }
  .elementor-template-library-template-local .elementor-template-library-template-more-toggle {
    -webkit-box-flex: 1;
        -ms-flex-positive: 1;
            flex-grow: 1;
    text-align: left; }
    .elementor-template-library-template-local .elementor-template-library-template-more-toggle i {
      font-size: 16px; }

#elementor-template-library-preview {
  height: 100%;
  overflow: hidden; }
  #elementor-template-library-preview iframe {
    height: 150%;
    -webkit-transform: scale(0.666) translateX(25%) translateY(-25%);
        -ms-transform: scale(0.666) translateX(25%) translateY(-25%);
            transform: scale(0.666) translateX(25%) translateY(-25%); }
    @media (max-width: 1439px) {
      #elementor-template-library-preview iframe {
        width: 1440px; } }
    @media (min-width: 1440px) {
      #elementor-template-library-preview iframe {
        width: 1710px; } }

.elementor-template-library-blank-icon {
  font-size: 65px;
  margin-top: 45px;
  color: #c2cbd2;
  line-height: 1; }
  .elementor-template-library-blank-icon img {
    width: 70px; }
  .elementor-template-library-blank-icon .elementor-template-library-no-results {
    width: 200px; }

.elementor-template-library-blank-title {
  font-size: 30px;
  margin-top: 40px; }
  @media (max-width: 1439px) {
    .elementor-template-library-blank-title {
      font-size: 25px; } }

.elementor-template-library-blank-message {
  font-size: 18px;
  color: #a4afb7;
  margin-top: 15px;
  font-weight: 300; }
  @media (max-width: 1439px) {
    .elementor-template-library-blank-message {
      font-size: 16px;
      margin-top: 10px; } }

#elementor-template-library-save-template-form {
  margin-top: 40px;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  -webkit-box-pack: center;
      -ms-flex-pack: center;
          justify-content: center; }
  #elementor-template-library-save-template-form > * {
    height: 55px;
    font-size: 16px; }

#elementor-template-library-save-template-name {
  width: 500px;
  background-color: #fff;
  font-weight: 300;
  color: #a4afb7;
  padding-right: 25px;
  -webkit-border-radius: 0 3px 3px 0;
          border-radius: 0 3px 3px 0;
  border: none; }

#elementor-template-library-save-template-submit {
  width: 150px;
  -webkit-border-radius: 3px 0 0 3px;
          border-radius: 3px 0 0 3px; }
  #elementor-template-library-save-template-submit:hover {
    -webkit-box-shadow: none;
            box-shadow: none; }

#elementor-template-library-import-form {
  width: 95%;
  background-color: rgba(255, 255, 255, 0.5);
  padding: 60px;
  border: 2px dashed #d5dadf;
  margin: 35px auto;
  -webkit-transition: background-color 0.5s;
  -o-transition: background-color 0.5s;
  transition: background-color 0.5s; }
  #elementor-template-library-import-form:hover {
    background-color: rgba(255, 255, 255, 0.9); }
  #elementor-template-library-import-form-or {
    margin-top: 15px;
    font-size: 18px; }
  #elementor-template-library-import-form-label {
    margin-top: 20px;
    padding: 15px 35px;
    display: inline-block; }
  #elementor-template-library-import-form-input {
    display: none; }
  #elementor-template-library-import-form.elementor-drag-over {
    border: 3px dashed #71d7f7; }

#elementor-template-library-import .elementor-template-library-blank-icon {
  margin-top: 0; }

#elementor-template-library-import .elementor-template-library-blank-message {
  margin-top: 20px; }

.e-route-library-connect #elementor-template-library-modal .dialog-message {
  max-height: 95vh;
  padding: 100px 0 0;
  min-height: 550px; }

#elementor-template-library-connect-logo {
  font-size: 20px; }

#elementor-template-library-connect__button {
  display: inline-block;
  position: relative;
  z-index: 1;
  margin-top: 25px;
  padding: 12px 24px;
  font-size: 14px; }

#elementor-template-library-connect__background-image-left-1 {
  right: 22.4%;
  bottom: -29%;
  -webkit-animation: 1.5s fadeIn, 1.5s slideDown, 3.5s mover 1.5s infinite alternate;
          animation: 1.5s fadeIn, 1.5s slideDown, 3.5s mover 1.5s infinite alternate; }

#elementor-template-library-connect__background-image-left-2 {
  right: 46.25%;
  bottom: -15.5%;
  -webkit-animation: 3s fadeIn, 3s slideDown, 2s mover 3s infinite alternate;
          animation: 3s fadeIn, 3s slideDown, 2s mover 3s infinite alternate; }

#elementor-template-library-connect__background-image-right-1 {
  left: 37%;
  bottom: -41%;
  -webkit-animation: 2.5s fadeIn, 2.5s slideDown, 2s mover 2.5s infinite alternate;
          animation: 2.5s fadeIn, 2.5s slideDown, 2s mover 2.5s infinite alternate; }

#elementor-template-library-connect__background-image-right-2 {
  left: 48%;
  bottom: -12.5%;
  -webkit-animation: 1.5s fadeIn, 1.5s slideDown, 1.5s mover 1.5s infinite alternate;
          animation: 1.5s fadeIn, 1.5s slideDown, 1.5s mover 1.5s infinite alternate; }

.elementor-template-library-connect__background-image {
  position: absolute; }

.elementor-template-library-blank-footer {
  position: absolute;
  bottom: 70px;
  left: 50%;
  -webkit-transform: translateX(-50%);
      -ms-transform: translateX(-50%);
          transform: translateX(-50%);
  color: #a4afb7;
  font-style: italic; }
  @media (max-height: 700px) {
    .elementor-template-library-blank-footer {
      display: none; } }

#elementor-template-library-footer-banner {
  padding-bottom: 45px; }
  #elementor-template-library-footer-banner i {
    color: #c2cbd2;
    font-size: 56px;
    margin-top: 40px; }
  #elementor-template-library-footer-banner .elementor-nerd-box-icon {
    margin-top: 70px; }
  #elementor-template-library-footer-banner .elementor-excerpt {
    color: #a4afb7;
    font-size: 15px;
    font-weight: 500;
    margin-top: 20px; }

#elementor-template-library-templates-empty {
  width: 100%;
  margin-top: 40px; }

#elementor-template-library-error-dialog .dialog-message {
  text-align: start; }

#elementor-template-library-error-info {
  margin-top: 10px; }

@media (max-width: 1439px) {
  .elementor-template-library-local-column-1 {
    width: 33%; }
  .elementor-template-library-local-column-2 {
    width: 10%; }
  .elementor-template-library-local-column-3 {
    width: 15%; }
  .elementor-template-library-local-column-4 {
    width: 15%; }
  .elementor-template-library-local-column-5 {
    width: 27%; } }

@media (min-width: 1440px) {
  .elementor-template-library-local-column-1 {
    width: 25%; }
  .elementor-template-library-local-column-2 {
    width: 17%; }
  .elementor-template-library-local-column-3 {
    width: 17%; }
  .elementor-template-library-local-column-4 {
    width: 17%; }
  .elementor-template-library-local-column-5 {
    width: 24%; } }

@media (max-width: 1024px) {
  .elementor-template-library-local-column-3 {
    display: none; }
  .elementor-template-library-local-column-5 {
    width: 41%; } }

.elementor-tags-list {
  display: none;
  position: absolute;
  width: 260px;
  max-height: 300px;
  overflow: auto;
  padding-bottom: 5px;
  background-color: #fff;
  border: 1px solid #a4afb7;
  -webkit-border-radius: 3px;
          border-radius: 3px;
  z-index: 10000; }
  .elementor-tags-list__group-title {
    color: #495157;
    font-weight: bold;
    font-size: 12px;
    padding: 10px 15px;
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center; }
    .elementor-tags-list__group-title .eicon-info-circle {
      padding-left: 5px;
      color: #71d7f7;
      font-size: 14px; }
  .elementor-tags-list__item {
    font-size: 10px;
    padding: 6px 15px;
    cursor: pointer; }
    .elementor-tags-list__item:before {
      content: '>';
      font-size: 8px;
      padding-left: 5px; }
    .elementor-tags-list__item:hover {
      background-color: #e6e9ec; }
  .elementor-tags-list__teaser {
    border-top: 2px solid #d5dadf;
    padding-top: 4px;
    margin-top: 4px; }
    .elementor-tags-list__teaser-title {
      color: #6d7882; }
    .elementor-tags-list__teaser-text {
      padding: 2px 15px 8px;
      line-height: 1.5;
      font-size: 12px; }
    .elementor-tags-list__teaser-link {
      color: #93003c;
      text-decoration: underline;
      font-style: italic;
      font-weight: bold; }

.elementor-dynamic-cover {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  width: 100%;
  height: 27px;
  -webkit-box-sizing: border-box;
          box-sizing: border-box; }
  .elementor-dynamic-cover__title {
    padding: 0 8px;
    -webkit-box-flex: 1;
        -ms-flex-positive: 1;
            flex-grow: 1;
    white-space: nowrap;
    -o-text-overflow: ellipsis;
       text-overflow: ellipsis;
    overflow: hidden; }
  .elementor-dynamic-cover__settings, .elementor-dynamic-cover__remove {
    color: #c2cbd2;
    cursor: pointer;
    -webkit-transition: all 0.3s;
    -o-transition: all 0.3s;
    transition: all 0.3s; }
    .elementor-dynamic-cover__settings:hover, .elementor-dynamic-cover__remove:hover {
      color: #a4afb7; }
  .elementor-control-type-wysiwyg .elementor-dynamic-cover {
    margin-top: 10px; }

.elementor-tag-settings-popup {
  position: absolute;
  width: 260px;
  background-color: #e6e9ec;
  -webkit-box-shadow: 1px 1px 10px rgba(0, 0, 0, 0.3);
          box-shadow: 1px 1px 10px rgba(0, 0, 0, 0.3);
  z-index: 1; }
  .elementor-tag-settings-popup:before {
    content: '';
    position: absolute;
    top: -20px;
    right: 5px;
    border: 10px solid transparent;
    border-bottom-color: #fff; }
  .elementor-tag-settings-popup .elementor-control-type-section:first-child {
    margin: 0; }

.elementor-tag-controls-stack-empty {
  background-color: #fff;
  padding: 10px;
  font-size: 13px;
  text-align: center; }

.elementor-control-dynamic-switcher {
  display: -webkit-inline-box;
  display: -ms-inline-flexbox;
  display: inline-flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  -webkit-box-pack: center;
      -ms-flex-pack: center;
          justify-content: center;
  -ms-flex-negative: 0;
      flex-shrink: 0;
  height: 27px;
  cursor: pointer;
  border: 1px solid #d5dadf;
  -webkit-border-radius: 3px;
          border-radius: 3px;
  background: #fff; }
  .elementor-control-dynamic-switcher.e-control-tool {
    height: 20px;
    border: 0; }
  .elementor-control-dynamic-switcher-wrapper {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex; }
  .elementor-control-dynamic-switcher .eicon-database {
    font-size: 12px; }

.elementor-control-dynamic-value .elementor-control-tag-area,
.elementor-control-dynamic-value .elementor-control-dynamic-switcher,
.elementor-control-dynamic-value .e-global__popover-toggle {
  display: none; }

#elementor-toast {
  position: absolute;
  width: 280px;
  padding: 20px;
  -webkit-border-radius: 5px;
          border-radius: 5px;
  color: #d5dadf;
  background-color: rgba(0, 0, 0, 0.8);
  z-index: 10000; }
  #elementor-toast .dialog-message {
    font-size: 13px; }
  #elementor-toast .dialog-buttons-wrapper {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-pack: end;
        -ms-flex-pack: end;
            justify-content: flex-end;
    margin-top: 15px; }
  #elementor-toast .dialog-button {
    color: #fcb92c;
    margin: 0 5px;
    text-transform: uppercase;
    cursor: pointer; }
    #elementor-toast .dialog-button:last-child {
      margin-left: 0; }

.elementor-context-menu {
  position: absolute;
  width: 200px;
  background-color: #fff;
  border: 1px solid #e6e9ec;
  -webkit-border-radius: 3px;
          border-radius: 3px;
  -webkit-box-shadow: 0 2px 10px 0 rgba(0, 0, 0, 0.09);
          box-shadow: 0 2px 10px 0 rgba(0, 0, 0, 0.09);
  -webkit-user-select: none;
     -moz-user-select: none;
      -ms-user-select: none;
          user-select: none;
  z-index: 101; }
  .elementor-context-menu-list__group {
    padding: 5px 0; }
    .elementor-context-menu-list__group:not(:last-child) {
      border-bottom: 1px solid #e6e9ec; }
  .elementor-context-menu-list__item {
    padding: 5px 10px;
    padding-left: 20px;
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    cursor: pointer; }
    .elementor-context-menu-list__item--disabled {
      cursor: default;
      color: #d5dadf; }
    .elementor-context-menu-list__item:not(.elementor-context-menu-list__item--disabled):hover {
      background-color: #71d7f7; }
      .elementor-context-menu-list__item:not(.elementor-context-menu-list__item--disabled):hover > * {
        color: #fff; }
    .elementor-context-menu-list__item__icon {
      width: 20px;
      color: #c2cbd2; }
    .elementor-context-menu-list__item__title {
      -webkit-box-flex: 1;
          -ms-flex-positive: 1;
              flex-grow: 1;
      white-space: nowrap;
      -o-text-overflow: ellipsis;
         text-overflow: ellipsis;
      overflow: hidden; }
    .elementor-context-menu-list__item__shortcut {
      color: #d5dadf; }
    .elementor-context-menu-list__item.elementor-context-menu-list__item-delete:not(.elementor-context-menu-list__item--disabled):hover {
      background-color: #d72b3f; }
  .elementor-context-menu .eicon-pro-icon {
    color: #fcb92c; }

#elementor-hotkeys {
  text-align: right; }
  #elementor-hotkeys__content {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    width: 100%;
    overflow: hidden;
    margin-bottom: 30px; }
    @media (max-width: 1024px) {
      #elementor-hotkeys__content {
        -webkit-box-orient: vertical;
        -webkit-box-direction: normal;
            -ms-flex-direction: column;
                flex-direction: column; } }
  #elementor-hotkeys__actions .elementor-hotkeys__list {
    -webkit-border-radius: 0 3px 3px 0;
            border-radius: 0 3px 3px 0; }
    @media (max-width: 1024px) {
      #elementor-hotkeys__actions .elementor-hotkeys__list {
        -webkit-border-radius: 3px;
                border-radius: 3px; } }
  @media (min-width: 1025px) {
    #elementor-hotkeys__actions .elementor-hotkeys__header,
    #elementor-hotkeys__actions .elementor-hotkeys__list {
      padding-left: 25px; } }
  @media (min-width: 1440px) {
    #elementor-hotkeys__actions .elementor-hotkeys__header,
    #elementor-hotkeys__actions .elementor-hotkeys__list {
      padding-left: 50px; } }
  #elementor-hotkeys__navigation .elementor-hotkeys__list {
    -webkit-border-radius: 3px 0 0 3px;
            border-radius: 3px 0 0 3px; }
    @media (max-width: 1024px) {
      #elementor-hotkeys__navigation .elementor-hotkeys__list {
        -webkit-border-radius: 3px;
                border-radius: 3px; } }
  @media (min-width: 1025px) {
    #elementor-hotkeys__navigation .elementor-hotkeys__header {
      padding-right: 25px; } }
  @media (min-width: 1440px) {
    #elementor-hotkeys__navigation .elementor-hotkeys__header {
      padding-right: 50px; } }
  @media (min-width: 1025px) {
    #elementor-hotkeys__navigation .elementor-hotkeys__list {
      padding-right: 15px; } }
  @media (min-width: 1440px) {
    #elementor-hotkeys__navigation .elementor-hotkeys__list {
      padding-right: 40px; } }

.elementor-hotkeys__col {
  width: 50%; }
  @media (max-width: 1024px) {
    .elementor-hotkeys__col {
      width: 100%; } }

.elementor-hotkeys__header, .elementor-hotkeys__list {
  width: 100%; }

.elementor-hotkeys__header {
  padding: 10px 30px;
  font-weight: 500; }
  @media (max-width: 479px) {
    .elementor-hotkeys__header {
      padding-right: 10px;
      padding-left: 10px; } }

.elementor-hotkeys__list {
  background-color: #ffffff;
  height: calc(100% - 42px);
  padding: 10px 20px; }
  @media (max-width: 479px) {
    .elementor-hotkeys__list {
      padding: 0; } }
  @media (max-width: 1024px) {
    .elementor-hotkeys__list {
      margin-bottom: 30px; } }
  @media (max-width: 1024px) {
    .elementor-hotkeys__list {
      height: auto; } }

.elementor-hotkeys__item {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  padding: 20px 10px;
  border-bottom: 1px solid #eceeef; }
  .elementor-hotkeys__item:last-child {
    margin-bottom: 30px; }
    @media (max-width: 479px) {
      .elementor-hotkeys__item:last-child {
        margin-bottom: 0; } }
  .elementor-hotkeys__item--label {
    font-size: 13px;
    font-weight: 400;
    -webkit-box-flex: 1;
        -ms-flex-positive: 1;
            flex-grow: 1; }
  .elementor-hotkeys__item--shortcut {
    -webkit-box-flex: 0;
        -ms-flex-positive: 0;
            flex-grow: 0;
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-orient: horizontal;
    -webkit-box-direction: reverse;
        -ms-flex-direction: row-reverse;
            flex-direction: row-reverse; }
    .elementor-hotkeys__item--shortcut span {
      position: relative;
      background-color: #eceeef;
      padding: 5px 12px;
      margin-right: 27px;
      -webkit-border-radius: 3px;
              border-radius: 3px; }
      @media (max-width: 479px) {
        .elementor-hotkeys__item--shortcut span {
          padding: 4px 9px;
          margin-right: 23px; } }
      .elementor-hotkeys__item--shortcut span:after {
        content: '+';
        position: absolute;
        right: -18px;
        width: 9px;
        text-align: center; }
        @media (max-width: 479px) {
          .elementor-hotkeys__item--shortcut span:after {
            right: -16px; } }
      .elementor-hotkeys__item--shortcut span:last-child {
        margin-right: 0; }
        .elementor-hotkeys__item--shortcut span:last-child:after {
          display: none; }

.ui-resizable-n {
  top: -5px; }

.ui-resizable-e {
  right: -5px; }

.ui-resizable-s {
  bottom: -5px; }

.ui-resizable-w {
  left: -5px; }

.ui-resizable-ne {
  top: -5px;
  right: -5px; }

.ui-resizable-nw {
  top: -5px;
  left: -5px; }

.ui-resizable-se {
  bottom: -5px;
  right: -5px; }

.ui-resizable-sw {
  bottom: -5px;
  left: -5px; }

.ui-resizable-n, .ui-resizable-s {
  left: 0;
  height: 10px;
  width: 100%;
  cursor: ns-resize; }

.ui-resizable-e, .ui-resizable-w {
  top: 0;
  height: 100%;
  width: 10px;
  cursor: ew-resize; }

.ui-resizable-ne, .ui-resizable-nw, .ui-resizable-se, .ui-resizable-sw {
  height: 15px;
  width: 15px; }

.ui-resizable-nw, .ui-resizable-se {
  cursor: nwse-resize; }

.ui-resizable-ne, .ui-resizable-sw {
  cursor: nesw-resize; }

.ui-resizable-handle {
  position: absolute; }

.ui-resizable-resizing {
  pointer-events: none; }

body {
  --e-editor-navigator-width: 240px; }

#elementor-navigator {
  position: fixed;
  top: 100px;
  width: var(--e-editor-navigator-width);
  height: 50vh;
  left: 30px;
  background-color: #fff;
  -webkit-box-shadow: 0 2px 20px 0 rgba(0, 0, 0, 0.1);
          box-shadow: 0 2px 20px 0 rgba(0, 0, 0, 0.1);
  -webkit-user-select: none;
     -moz-user-select: none;
      -ms-user-select: none;
          user-select: none;
  overflow: hidden;
  z-index: 100;
  display: none; }
  body.elementor-navigator-docked #elementor-navigator {
    top: 0;
    left: 0;
    height: 100%; }
  body:not(.elementor-navigator-docked) #elementor-navigator {
    -webkit-border-radius: 5px;
            border-radius: 5px; }
  #elementor-navigator__inner {
    height: 100%;
    background-color: #e6e9ec; }
  #elementor-navigator__header {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center;
    -webkit-box-pack: justify;
        -ms-flex-pack: justify;
            justify-content: space-between;
    padding: 12px 10px;
    background-color: #fff;
    border-bottom: 1px solid #e6e9ec;
    cursor: move; }
  #elementor-navigator__close, #elementor-navigator__toggle-all {
    -webkit-transition: color .5s;
    -o-transition: color .5s;
    transition: color .5s;
    cursor: pointer; }
    #elementor-navigator__close:not(:hover), #elementor-navigator__toggle-all:not(:hover) {
      color: #a4afb7; }
  #elementor-navigator__toggle-all {
    font-size: 13px; }
  #elementor-navigator__close {
    font-size: 11px; }
  #elementor-navigator__elements {
    height: calc(100% - 49px);
    overflow: auto;
    position: relative; }
    .elementor-navigator-docked #elementor-navigator__elements {
      height: calc(100% - 35px); }
    #elementor-navigator__elements .elementor-nerd-box {
      padding: 25px; }
  #elementor-navigator__footer {
    position: absolute;
    width: 100%;
    left: 0;
    bottom: 0;
    text-align: center;
    background-color: #fff;
    border-top: 1px solid #e6e9ec;
    color: #a4afb7; }
    .elementor-navigator-docked #elementor-navigator__footer {
      display: none; }

.elementor-navigator__item {
  position: relative;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  height: 30px;
  font-size: 11px;
  border-bottom: 1px solid #e6e9ec;
  cursor: pointer;
  -webkit-transition: padding .5s linear;
  -o-transition: padding .5s linear;
  transition: padding .5s linear;
  overflow: hidden; }
  .elementor-navigator__item:not(.elementor-active) .elementor-navigator__element__list-toggle i {
    -webkit-transform: rotate(90deg);
        -ms-transform: rotate(90deg);
            transform: rotate(90deg); }
  .elementor-navigator__item > * {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center; }
  .elementor-navigator__item + .elementor-navigator__elements {
    display: none; }

.elementor-navigator__elements .elementor-empty-view {
  padding: 10px;
  border-bottom: 1px solid #e6e9ec; }
  .elementor-navigator__elements .elementor-empty-view__title {
    margin-right: 23px;
    color: #c2cbd2;
    font-size: 10px;
    font-style: italic; }

.elementor-navigator__elements .ui-sortable-helper {
  background-color: #fff;
  -webkit-box-shadow: 1px 2px 5px 0 rgba(0, 0, 0, 0.1);
          box-shadow: 1px 2px 5px 0 rgba(0, 0, 0, 0.1);
  -webkit-transform: rotate(4deg);
      -ms-transform: rotate(4deg);
          transform: rotate(4deg);
  border: 1px solid #e6e9ec;
  pointer-events: none; }

.elementor-navigator__elements .ui-sortable-placeholder {
  background-color: #f1f3f5; }

.elementor-navigator__element.elementor-dragging-on-child > .elementor-navigator__elements > .elementor-empty-view {
  border-top: 2px solid #71d7f7; }
  .elementor-navigator__element.elementor-dragging-on-child > .elementor-navigator__elements > .elementor-empty-view .elementor-empty-view__title {
    display: none; }
  .elementor-navigator__element.elementor-dragging-on-child > .elementor-navigator__elements > .elementor-empty-view + .ui-sortable-placeholder {
    display: none; }

.elementor-navigator__element:not(.elementor-navigator__element--has-children) .elementor-navigator__element__list-toggle {
  visibility: hidden; }

.elementor-navigator__element:not(.elementor-navigator__element--hidden) > .elementor-navigator__item .elementor-navigator__element__toggle {
  color: #71d7f7; }

.elementor-navigator__element:not(.elementor-navigator__element--hidden) > .elementor-navigator__item:not(:hover) .elementor-navigator__element__toggle {
  display: none; }

.elementor-navigator__element:not(.elementor-navigator__element--hidden) > .elementor-navigator__item.elementor-editing {
  background-color: #71d7f7; }
  .elementor-navigator__element:not(.elementor-navigator__element--hidden) > .elementor-navigator__item.elementor-editing > * {
    color: #fff; }

.elementor-navigator__element__list-toggle {
  margin-left: 7px;
  -webkit-transition: -webkit-transform .3s;
  transition: -webkit-transform .3s;
  -o-transition: transform .3s;
  transition: transform .3s;
  transition: transform .3s, -webkit-transform .3s;
  color: #a4afb7; }

.elementor-navigator__element__element-type {
  margin-left: 8px; }

.elementor-navigator__element__title {
  -webkit-box-flex: 1;
      -ms-flex-positive: 1;
          flex-grow: 1;
  overflow: hidden; }
  .elementor-navigator__element__title__text {
    white-space: nowrap;
    -webkit-user-select: text; }
    .elementor-navigator__element__title__text[contenteditable="true"] {
      outline: none;
      color: #6d7882;
      background-color: #fff;
      padding: 2px 3px;
      -webkit-box-shadow: 0 0 4px rgba(0, 0, 0, 0.2);
              box-shadow: 0 0 4px rgba(0, 0, 0, 0.2); }
    .elementor-navigator__element__title__text:not([contenteditable="true"]) {
      white-space: nowrap;
      -o-text-overflow: ellipsis;
         text-overflow: ellipsis;
      overflow: hidden; }

.elementor-navigator__element__toggle {
  position: absolute;
  left: 15px;
  height: 100%;
  z-index: 0;
  font-size: 13px; }

.elementor-navigator__element__indicators {
  position: relative;
  -webkit-transition: -webkit-transform .5s;
  transition: -webkit-transform .5s;
  -o-transition: transform .5s;
  transition: transform .5s;
  transition: transform .5s, -webkit-transform .5s;
  padding-right: 5px;
  z-index: 91; }
  .elementor-navigator__element__indicators:not(:hover) {
    -webkit-transform: translateX(calc(-100% + 8px));
        -ms-transform: translateX(calc(-100% + 8px));
            transform: translateX(calc(-100% + 8px)); }

.elementor-navigator__element__indicator {
  height: 100%;
  width: 31px;
  display: -webkit-inline-box;
  display: -ms-inline-flexbox;
  display: inline-flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  -webkit-box-pack: center;
      -ms-flex-pack: center;
          justify-content: center;
  color: #6d7882;
  background-color: #fff;
  border-right: 1px solid #e6e9ec; }
  .elementor-navigator__element__indicator:first-child {
    border-right: 3px solid #71d7f7; }
    .elementor-editing .elementor-navigator__element__indicator:first-child {
      border-color: #41c9f4; }
  .elementor-navigator__element__indicator:hover {
    color: #495157; }

.elementor-navigator__element--hidden .elementor-navigator__element__title,
.elementor-navigator__element--hidden .elementor-navigator__element__toggle {
  opacity: .5; }

.elementor-navigator__element-column {
  background-color: #fafbfb; }
  .elementor-navigator__element-column > .elementor-navigator__item .elementor-navigator__element__element-type {
    color: #a4afb7; }

.elementor-navigator__element-section {
  background-color: #fff; }

#elementor-notice-bar {
  position: absolute;
  width: 100%;
  bottom: 0;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  height: 40px;
  color: #fff;
  background-color: #6d7882;
  padding: 0 50px; }
  #elementor-notice-bar__message {
    padding-right: 15px;
    -webkit-box-flex: 1;
        -ms-flex-positive: 1;
            flex-grow: 1; }
    #elementor-notice-bar__message a {
      text-decoration: underline; }
  #elementor-notice-bar__action {
    text-transform: uppercase; }
  #elementor-notice-bar__close {
    margin: 0 20px;
    cursor: pointer; }
  #elementor-notice-bar i {
    font-size: 16px;
    opacity: .9; }
  #elementor-notice-bar a {
    color: #fff; }
  #elementor-notice-bar a,
  #elementor-notice-bar i {
    -webkit-transition: all 0.3s;
    -o-transition: all 0.3s;
    transition: all 0.3s; }
    #elementor-notice-bar a:hover,
    #elementor-notice-bar i:hover {
      color: #D4D4D4; }

body:not(.elementor-device-desktop) #elementor-notice-bar {
  display: none; }

#elementor-fatal-error-dialog.elementor-preview-loading-error .dialog-header {
  color: #495157; }

#elementor-fatal-error-dialog.elementor-preview-loading-error .dialog-message a {
  color: #6d7882;
  text-decoration: underline;
  font-style: italic; }

#elementor-preview-debug-link-text {
  display: inline-block; }

#elementor-icons-manager-modal .dialog-message {
  padding: 0;
  height: 700px; }

#elementor-icons-manager-modal .dialog-content {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex; }

#elementor-icons-manager-modal .dialog-buttons-wrapper {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex; }

#elementor-icons-manager__wrapper {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex; }

@media (max-width: 479px) {
  #elementor-icons-manager__sidebar {
    display: none; } }

#elementor-icons-manager__tab-links {
  margin-top: 30px; }

#elementor-icons-manager__upload {
  margin: 20px 45px;
  padding-top: 35px;
  border-top: 1px solid #e6e9ec;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  -webkit-box-pack: justify;
      -ms-flex-pack: justify;
          justify-content: space-between; }
  @media (max-width: 1439px) {
    #elementor-icons-manager__upload {
      margin: 20px 25px; } }
  #elementor-icons-manager__upload__title {
    color: #a4afb7;
    font-size: 11px;
    text-transform: uppercase; }

#elementor-icons-manager__main {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
      -ms-flex-direction: column;
          flex-direction: column;
  padding: 30px 80px 0; }
  @media (max-width: 1439px) {
    #elementor-icons-manager__main {
      padding: 30px 50px 0; } }
  @media (max-width: 479px) {
    #elementor-icons-manager__main {
      width: 100%; } }

#elementor-icons-manager__search {
  position: relative; }
  #elementor-icons-manager__search input {
    padding: 8px 15px;
    background-color: #fff;
    border: none; }
    #elementor-icons-manager__search input::-webkit-input-placeholder {
      font-style: italic; }
    #elementor-icons-manager__search input::-moz-placeholder {
      font-style: italic; }
    #elementor-icons-manager__search input::-ms-input-placeholder {
      font-style: italic; }
    #elementor-icons-manager__search input::placeholder {
      font-style: italic; }
  #elementor-icons-manager__search i {
    position: absolute;
    top: 50%;
    -webkit-transform: translateY(-50%);
        -ms-transform: translateY(-50%);
            transform: translateY(-50%);
    left: 15px; }

#elementor-icons-manager__tab__wrapper {
  overflow: auto;
  margin: 25px -15px 0;
  padding: 0 15px 15px; }

#elementor-icons-manager__tab__title {
  color: #556068;
  font-size: 16px;
  font-weight: 500;
  text-align: right; }
  @media (max-width: 479px) {
    #elementor-icons-manager__tab__title {
      display: none; } }

#elementor-icons-manager__tab__content {
  display: grid;
  grid-template-columns: repeat(7, 1fr);
  grid-gap: 20px;
  margin: 20px 0; }
  @media (max-width: 1439px) {
    #elementor-icons-manager__tab__content {
      grid-template-columns: repeat(6, 1fr); } }
  @media (max-width: 1024px) {
    #elementor-icons-manager__tab__content {
      grid-template-columns: repeat(5, 1fr); } }
  @media (max-width: 767px) {
    #elementor-icons-manager__tab__content {
      grid-template-columns: repeat(4, 1fr); } }
  @media (max-width: 479px) {
    #elementor-icons-manager__tab__content {
      grid-template-columns: repeat(3, 1fr); } }

#elementor-icons-manager__promotion {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
      -ms-flex-direction: column;
          flex-direction: column;
  padding-top: 70px; }
  #elementor-icons-manager__promotion__icon {
    font-size: 60px;
    color: #c2cbd2; }
  #elementor-icons-manager__promotion__text {
    width: 300px;
    font-size: 16px;
    padding-top: 25px; }
  #elementor-icons-manager__promotion__link {
    margin-top: 20px; }

.elementor-icons-manager__tab-link {
  padding: 15px 45px 15px 0;
  font-size: 14px;
  color: #6d7882;
  text-align: right;
  cursor: pointer;
  position: relative; }
  .elementor-icons-manager__tab-link i {
    font-size: 20px;
    padding-left: 15px;
    color: #a4afb7; }
  @media (max-width: 1439px) {
    .elementor-icons-manager__tab-link {
      padding: 15px 25px 15px 15px;
      font-size: 11px; }
      .elementor-icons-manager__tab-link i {
        font-size: 15px; } }
  @media (max-width: 1024px) {
    .elementor-icons-manager__tab-link i {
      display: none; } }
  .elementor-icons-manager__tab-link.elementor-active {
    background-color: #fff;
    -webkit-box-shadow: 0 6px 20px 0 rgba(0, 0, 0, 0.1);
            box-shadow: 0 6px 20px 0 rgba(0, 0, 0, 0.1); }
    .elementor-icons-manager__tab-link.elementor-active:after {
      content: '';
      position: absolute;
      height: 100%;
      width: 5px;
      top: 0;
      right: 0;
      background-color: #71d7f7; }
    .elementor-icons-manager__tab-link.elementor-active i {
      color: #71d7f7; }

.elementor-icons-manager__tab__item {
  position: relative;
  height: 0;
  padding-bottom: 100%;
  background-color: #fff;
  -webkit-box-shadow: 0 1px 12px rgba(0, 0, 0, 0.05);
          box-shadow: 0 1px 12px rgba(0, 0, 0, 0.05);
  -webkit-border-radius: 3px;
          border-radius: 3px;
  cursor: pointer;
  -webkit-transition: all 0.3s;
  -o-transition: all 0.3s;
  transition: all 0.3s;
  overflow: hidden; }
  .elementor-icons-manager__tab__item:hover {
    -webkit-box-shadow: 0 1px 14px rgba(0, 0, 0, 0.16);
            box-shadow: 0 1px 14px rgba(0, 0, 0, 0.16); }
  .elementor-icons-manager__tab__item.elementor-selected {
    -webkit-box-shadow: 0 1px 12px rgba(0, 0, 0, 0.05), 0 0 0 3px #71d7f7;
            box-shadow: 0 1px 12px rgba(0, 0, 0, 0.05), 0 0 0 3px #71d7f7; }
  .elementor-icons-manager__tab__item__content {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-orient: vertical;
    -webkit-box-direction: normal;
        -ms-flex-direction: column;
            flex-direction: column;
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center;
    width: 100%;
    position: absolute;
    top: 50%;
    left: 50%;
    -webkit-transform: translate(-50%, -50%);
        -ms-transform: translate(-50%, -50%);
            transform: translate(-50%, -50%);
    padding: 1px; }
  .elementor-icons-manager__tab__item__icon {
    font-size: 25px;
    color: #6d7882; }
  .elementor-icons-manager__tab__item__name {
    color: #c2cbd2;
    font-size: 11px;
    padding: 13px 20px 0;
    max-width: 100%;
    white-space: nowrap;
    -o-text-overflow: ellipsis;
       text-overflow: ellipsis;
    overflow: hidden; }

#elementor-enable-fa5-dialog a {
  font-style: italic;
  text-decoration: underline; }

#elementor-enable-fa5-dialog .dialog-confirm-ok {
  color: #39b54a; }

.elementor-color-picker__header {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
      -ms-flex-pack: justify;
          justify-content: space-between;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  font-weight: bold;
  padding: 10px;
  -webkit-box-shadow: 0 2px 8px rgba(0, 0, 0, 0.1);
          box-shadow: 0 2px 8px rgba(0, 0, 0, 0.1); }

.e-color-picker__tools {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex; }

.e-control-color--no-value .pcr-button {
  background-image: -webkit-linear-gradient(315deg, transparent 46%, #ff3030 50%, transparent 54%);
  background-image: -o-linear-gradient(315deg, transparent 46%, #ff3030 50%, transparent 54%);
  background-image: linear-gradient(135deg, transparent 46%, #ff3030 50%, transparent 54%);
  -webkit-background-size: cover;
          background-size: cover;
  background-color: transparent;
  border: 1px solid #d5dadf; }

.pcr-app[data-theme=monolith] {
  padding: 0; }

.pcr-result {
  border-right-width: 1px;
  -webkit-border-radius: 3px;
          border-radius: 3px; }

.pcr-selection, .pcr-interaction {
  padding: 0 20px; }

.pcr-interaction {
  padding-bottom: 20px; }

.pcr .elementor-control-dynamic-switcher {
  height: 20px;
  border: 0; }

.select2-container {
  width: 100% !important;
  outline: none;
  z-index: 9999;
  font-size: 12px; }
  .select2-container .e-select2-placeholder {
    color: #a4afb7; }
  .select2-container.select2-container--default .select2-selection--single {
    height: 27px; }
    .select2-container.select2-container--default .select2-selection--single .select2-selection__rendered {
      color: #6d7882;
      line-height: 27px; }
  .select2-container.select2-container--default .select2-selection--multiple {
    min-height: 27px;
    line-height: 0; }
    .select2-container.select2-container--default .select2-selection--multiple .select2-selection__clear {
      display: none; }
    .select2-container.select2-container--default .select2-selection--multiple .select2-selection__choice {
      background-color: #f1f3f5;
      line-height: 1.2;
      font-size: 10px;
      border: none;
      -webkit-border-radius: 0;
              border-radius: 0;
      padding: 2px 3px; }
      .select2-container.select2-container--default .select2-selection--multiple .select2-selection__choice.select2-selection__e-plus-button {
        cursor: pointer;
        width: 16.67px;
        text-indent: -9999px;
        position: relative; }
        .select2-container.select2-container--default .select2-selection--multiple .select2-selection__choice.select2-selection__e-plus-button:after {
          content: '\e815';
          font-family: "eicons";
          color: #a4afb7;
          text-indent: 0;
          position: absolute;
          left: 0;
          top: 0;
          width: 100%;
          height: 100%;
          display: -webkit-box;
          display: -ms-flexbox;
          display: flex;
          -webkit-box-pack: center;
              -ms-flex-pack: center;
                  justify-content: center;
          -webkit-box-align: center;
              -ms-flex-align: center;
                  align-items: center; }
    .select2-container.select2-container--default .select2-selection--multiple .select2-selection__rendered {
      padding-bottom: 5px; }
    .select2-container.select2-container--default .select2-selection--multiple .select2-selection__choice__remove {
      color: #a4afb7;
      margin-left: 3px; }
  .select2-container:not(.select2-container--open):not(.select2-container--focus) .select2-selection--single,
  .select2-container:not(.select2-container--open):not(.select2-container--focus) .select2-selection--multiple {
    border-color: #d5dadf; }
  .select2-container.select2-container--open .select2-selection--single,
  .select2-container.select2-container--open .select2-selection--multiple, .select2-container.select2-container--focus .select2-selection--single,
  .select2-container.select2-container--focus .select2-selection--multiple {
    border-color: #a4afb7; }

.select2-selection {
  outline: none; }
  .select2-selection--single {
    height: 27px; }

.select2-selection__arrow {
  height: 27px;
  top: 0; }

.select2-results__option[aria-selected=true] {
  color: #495157; }
  .select2-results__option[aria-selected=true]:not(.select2-results__option--highlighted) {
    background-color: initial; }

.select2-dropdown {
  border-color: #a4afb7; }
  .select2-dropdown .select2-search__field {
    outline: none; }
/*# sourceMappingURL=editor-rtl.css.map */